import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { getConnectorIcon } from 'nimbus-wallet-management';
import { ExpandMore, Wallet } from '@mui/icons-material';
import { Avatar, Badge } from '@mui/material';
import { useEffect, useState } from 'react';
import { useTranslation } from 'react-i18next';
import { useLocation, useNavigate } from 'react-router-dom';
import { useAccount } from '../../hooks/useAccount.js';
import { useChain } from '../../hooks/useChain.js';
import { useHasExternalWalletProvider } from '../../providers/WalletProvider/useHasExternalWalletProvider.js';
import { useWidgetConfig } from '../../providers/WidgetProvider/WidgetProvider.js';
import { HiddenUI } from '../../types/widget.js';
import { navigationRoutes } from '../../utils/navigationRoutes.js';
import { shortenAddress } from '../../utils/wallet.js';
import { SmallAvatar } from '../SmallAvatar.js';
import { CloseDrawerButton } from './CloseDrawerButton.js';
import { DrawerWalletContainer, HeaderAppBar, WalletAvatar, WalletButton, } from './Header.style.js';
import { WalletMenu } from './WalletMenu.js';
import { WalletMenuContainer } from './WalletMenu.style.js';
import { ChainType } from '../../utils/chainType.js';
// @ts-ignore
import { useWallet as useSolanaWallet } from '@solana/wallet-adapter-react';
import { useTon } from '../../providers/WalletProvider/TVM/TVMBaseProvider.js';
import { useDisconnect } from 'wagmi';
import { useFieldValues } from '../../stores/form/useFieldValues.js';
import { FormKeyHelper } from '../../stores/form/types.js';
import { ChainId } from '../../types/base.js';
import { useFieldActions } from '../../stores/form/useFieldActions.js';
import { getDefaultValuesFromQueryString } from '../../stores/form/URLSearchParamsBuilder.js';
export const WalletHeader = () => {
    const { subvariant, hiddenUI } = useWidgetConfig();
    const { hasExternalProvider } = useHasExternalWalletProvider();
    return !hasExternalProvider &&
        subvariant !== 'split' &&
        !hiddenUI?.includes(HiddenUI.WalletMenu) ? (_jsx(HeaderAppBar, { elevation: 0, sx: { justifyContent: 'flex-end' }, children: _jsx(WalletMenuButton, {}) })) : null;
};
export const SplitWalletMenuButton = () => {
    const { hiddenUI } = useWidgetConfig();
    const { hasExternalProvider } = useHasExternalWalletProvider();
    return !hasExternalProvider && !hiddenUI?.includes(HiddenUI.WalletMenu) ? (_jsx(WalletMenuButton, {})) : null;
};
export const WalletMenuButton = () => {
    const { account, accounts } = useAccount();
    const { variant, hiddenUI, isUniversalSwap } = useWidgetConfig();
    // TODO: remove when enable other chain
    const { tonConnectUI } = useTon();
    const { disconnect } = useSolanaWallet();
    const evmDisconnect = useDisconnect();
    const wait = (time) => {
        return new Promise((resolve) => {
            setTimeout(() => {
                resolve(true);
            }, time);
        });
    };
    const handleDisconnectWallet = async () => {
        if (account.isConnected && isUniversalSwap) {
            if (account.chainType === ChainType.EVM) {
                if (account?.connector?.name === 'MetaMask') {
                    await wait(10000); // 10s
                    evmDisconnect.disconnect({
                        connector: account?.connector,
                    });
                }
                else {
                    evmDisconnect.disconnect({
                        connector: account?.connector,
                    });
                }
            }
        }
    };
    useEffect(() => {
        handleDisconnectWallet();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [account, isUniversalSwap, disconnect, tonConnectUI, evmDisconnect]);
    if (variant === 'drawer') {
        return (_jsxs(DrawerWalletContainer, { children: [account.isConnected ? (_jsx(ConnectedButton, { account: account, accounts: accounts })) : (_jsx(ConnectButton, {})), !hiddenUI?.includes(HiddenUI.DrawerCloseButton) ? (_jsx(CloseDrawerButton, { header: "wallet" })) : null] }));
    }
    return account.isConnected ? (_jsx(ConnectedButton, { account: account, accounts: accounts })) : (_jsx(ConnectButton, {}));
};
const ConnectButton = () => {
    const { t } = useTranslation();
    const { pathname } = useLocation();
    const { walletConfig, subvariant, variant } = useWidgetConfig();
    const navigate = useNavigate();
    const connect = async () => {
        if (walletConfig?.onConnect) {
            walletConfig.onConnect();
            return;
        }
        navigate(navigationRoutes.selectWallet);
    };
    return (_jsx(WalletButton, { subvariant: subvariant, endIcon: variant !== 'drawer' && subvariant !== 'split' ? _jsx(Wallet, {}) : undefined, startIcon: variant === 'drawer' || subvariant === 'split' ? (_jsx(Wallet, { sx: { marginLeft: -0.25 } })) : undefined, onClick: !pathname.includes(navigationRoutes.selectWallet) ? connect : undefined, children: t(`button.connectWallet`) }));
};
const ConnectedButton = ({ account, accounts, }) => {
    const [anchorEl, setAnchorEl] = useState(null);
    const { subvariant, fromToken } = useWidgetConfig();
    const [chainId] = useFieldValues(FormKeyHelper.getChainKey('from'));
    const { setUserAndDefaultValues } = useFieldActions();
    const selectedAccount = accounts.find((acc) => acc.chainId === chainId) || account;
    const { chain } = useChain(selectedAccount.chainId);
    const walletAddress = shortenAddress(selectedAccount.address);
    useEffect(() => {
        setTimeout(() => {
            const formValues = getDefaultValuesFromQueryString();
            if (!fromToken && !formValues.fromToken && !formValues.toToken) {
                if (chainId === ChainId.MOVE) {
                    setUserAndDefaultValues({
                        fromToken: '0x2::sui::SUI',
                        toToken: '0xc060006111016b8a020ad5b33834984a437aaa7d3c74c18e09a95d48aceab08c::coin::COIN',
                    });
                }
                if (chainId === ChainId.TON) {
                    setUserAndDefaultValues({
                        fromToken: '0:0000000000000000000000000000000000000000000000000000000000000000',
                        toToken: '0:b113a994b5024a16719f69139328eb759596c38a25f59028b146fecdc3621dfe',
                    });
                }
                if (chainId === ChainId.ECLIPSE) {
                    setUserAndDefaultValues({
                        fromToken: 'So11111111111111111111111111111111111111112',
                        toToken: 'AKEWE7Bgh87GPp171b4cJPSSZfmZwQ3KaqYqXoKLNAEE',
                    });
                }
                if (chainId === ChainId.SOL) {
                    setUserAndDefaultValues({
                        fromToken: '11111111111111111111111111111111',
                        toToken: 'EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v',
                    });
                }
            }
        }, 0);
    }, [chainId, fromToken, setUserAndDefaultValues]);
    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
        setAnchorEl(null);
    };
    return (_jsxs(_Fragment, { children: [_jsx(WalletButton, { subvariant: subvariant, endIcon: _jsx(ExpandMore, {}), startIcon: chain?.logoURI ? (_jsx(Badge, { overlap: "circular", anchorOrigin: { vertical: 'bottom', horizontal: 'right' }, badgeContent: _jsx(SmallAvatar, { src: chain?.logoURI, alt: chain?.name, sx: { width: 12, height: 12 }, children: chain?.name[0] }), children: _jsx(WalletAvatar, { src: getConnectorIcon(selectedAccount.connector), alt: selectedAccount.connector?.name, children: selectedAccount.connector?.name[0] }) })) : (_jsx(Avatar, { src: getConnectorIcon(selectedAccount.connector), alt: selectedAccount.connector?.name, sx: { width: 24, height: 24 }, children: selectedAccount.connector?.name[0] })), onClick: handleClick, children: walletAddress }), _jsx(WalletMenuContainer, { anchorEl: anchorEl, open: Boolean(anchorEl), onClose: handleClose, children: _jsx(WalletMenu, { onClose: handleClose }) })] }));
};
//# sourceMappingURL=WalletHeader.js.map