import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/* eslint-disable @typescript-eslint/no-unused-vars */
import { useRoutes } from '../../hooks/useRoutes.js';
import { useWidgetConfig } from '../../providers/WidgetProvider/WidgetProvider.js';
import { Box, Typography, Avatar } from '@mui/material';
import { Card } from '../Card/Card.js';
import { CardTitle } from '../Card/CardTitle.js';
import numeral from 'numeral';
import { useAccount } from '../../hooks/useAccount.js';
import { useChain } from '../../hooks/useChain.js';
import { useFieldValues } from '../../stores/form/useFieldValues.js';
import { useMemo } from 'react';
import { FormKeyHelper } from '../../stores/form/types.js';
import { ChainId } from '../../types/base.js';
export const RewardSwap = (props) => {
    const { rewardSwapData } = useWidgetConfig();
    const { routes } = useRoutes();
    const currentRoute = routes?.[0];
    const [fromChainId] = useFieldValues('fromChain');
    const { chain } = useChain(fromChainId);
    const { account } = useAccount({ chainType: chain?.chainType });
    const [chainId] = useFieldValues(FormKeyHelper.getChainKey('from'));
    const formatRewardSwapData = useMemo(() => {
        const GMPOINTReward = rewardSwapData?.filter((item) => item.type === 'GM_POINT') || [];
        if (account.isConnected) {
            if (account.chainType === 'EVM') {
                return rewardSwapData;
            }
            if (account.chainType === 'SVM') {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'SVM')
                    ?.concat(GMPOINTReward);
            }
            if (account.chainType === 'ECLIPSE') {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'ECLIPSE')
                    ?.concat(GMPOINTReward);
            }
            if (account.chainType === 'MVM') {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'SUI')
                    ?.concat(GMPOINTReward);
            }
            if (account.chainType === 'TVM') {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'TON')
                    ?.concat(GMPOINTReward);
            }
        }
        else {
            if (chainId === ChainId.MOVE) {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'SUI')
                    ?.concat(GMPOINTReward);
            }
            else if (chainId === ChainId.TON) {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'TON')
                    ?.concat(GMPOINTReward);
            }
            else if (chainId === ChainId.ECLIPSE) {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'ECLIPSE')
                    ?.concat(GMPOINTReward);
            }
            else if (chainId === ChainId.SOL) {
                return rewardSwapData
                    ?.filter((item) => item.chain === 'SOL')
                    ?.concat(GMPOINTReward);
            }
            else {
                return rewardSwapData;
            }
        }
    }, [chainId, account, rewardSwapData]) || [];
    if (rewardSwapData && rewardSwapData.length > 0) {
        return (_jsxs(Card, { ...props, children: [_jsx(CardTitle, { children: "Rewards" }), _jsx(Box, { p: 2, children: _jsx(Box, { sx: {
                            display: 'grid',
                            gridTemplateColumns: 'repeat(1, 1fr)',
                            gap: 2,
                        }, children: formatRewardSwapData.map((item, index) => (_jsxs(Box, { sx: {
                                display: 'flex',
                                alignItems: 'center',
                                gap: 1,
                                flexWrap: 'wrap',
                            }, children: [_jsx(Avatar, { src: item.logo, alt: item.symbol, sx: { width: 24, height: 24 } }), _jsx(Typography, { fontWeight: "600", children: item.symbol }), !!item.amount && !!currentRoute?.fromAmountUSD && (_jsx(Typography, { fontSize: 14, style: { opacity: '0.56' }, fontWeight: 600, children: numeral(Number(currentRoute.fromAmountUSD) * Number(item.amount)).format('0,0.00') }))] }, index))) }) })] }));
    }
    return null;
};
//# sourceMappingURL=RewardSwap.js.map