import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ExpandLess, ExpandMore } from '@mui/icons-material';
import { Box, Collapse, Typography } from '@mui/material';
import { useEffect, useState } from 'react';
import { useTranslation } from 'react-i18next';
import { useAccount } from '../../hooks/useAccount.js';
import { useWidgetConfig } from '../../providers/WidgetProvider/WidgetProvider.js';
import { Card } from '../Card/Card.js';
import { CardIconButton } from '../Card/CardIconButton.js';
import { CardLabel, CardLabelTypography } from '../Card/CardLabel.js';
import { StepActions } from '../StepActions/StepActions.js';
import { Token } from '../Token/Token.js';
import { TokenContainer } from './RouteCard.style.js';
import { RouteCardEssentials } from './RouteCardEssentials.js';
import { TokenPnLTypography } from '../TokenRate/TokenRate.style.js';
import axios from 'axios';
import { MOVE_CHAIN_ID } from '../../utils/constants.js';
export const RouteCard = ({ route, active, variant = 'default', expanded: defaulExpanded, ...other }) => {
    const { account } = useAccount();
    const { t } = useTranslation();
    const { subvariant } = useWidgetConfig();
    const [cardExpanded, setCardExpanded] = useState(defaulExpanded);
    const handleExpand = (e) => {
        e.stopPropagation();
        setCardExpanded((expanded) => !expanded);
    };
    const token = subvariant === 'custom'
        ? { ...route.fromToken, amount: BigInt(route?.fromAmount || 0) }
        : { ...route.toToken, amount: BigInt(route?.toAmount || 0) };
    const impactToken = subvariant !== 'custom'
        ? { ...route.fromToken, amount: BigInt(route?.fromAmount || 0) }
        : undefined;
    const tags = route.tags?.filter((tag) => tag === 'CHEAPEST' || tag === 'FASTEST');
    const [dataPnl, setDataPnL] = useState({
        pnl: 0,
        percent: 0,
    });
    const handleCalPnL = async (data, address) => {
        try {
            const formatAmountFrom = Number(data?.fromAmount) / 10 ** data?.fromToken?.decimals;
            const formatAmountTo = Number(data?.toAmount) / 10 ** data?.toToken?.decimals;
            const payload = {
                owner: address,
                from: {
                    address: data?.fromToken?.address,
                    symbol: data?.fromToken?.symbol,
                    quantity: formatAmountFrom,
                    price: Number(data?.fromToken?.priceUSD),
                },
                to: {
                    address: data?.toToken?.address,
                    symbol: data?.toToken?.symbol,
                    quantity: formatAmountTo,
                    price: Number(data?.toToken?.priceUSD),
                },
            };
            const response = await axios
                .post(`https://api.getnimbus.io/swap/pnl?chain=${data?.fromChainId}`, payload)
                .then((res) => res?.data?.data);
            if (response && response?.newRealizedPnL !== 0) {
                setDataPnL({
                    pnl: response?.newRealizedPnL - response?.currentRealizedPnL,
                    percent: Number(response?.cost) === 0
                        ? 0
                        : (response?.newRealizedPnL - response?.currentRealizedPnL) /
                            Number(response?.cost),
                });
            }
        }
        catch (error) {
            console.error(error);
        }
    };
    useEffect(() => {
        if (route?.fromChainId &&
            route?.fromChainId === MOVE_CHAIN_ID &&
            account?.isConnected) {
            handleCalPnL(route, account?.address || '');
        }
    }, [route, account]);
    const cardContent = (_jsxs(Box, { flex: 1, children: [subvariant !== 'refuel' && route.tags?.length ? (_jsx(Box, { display: "flex", alignItems: "center", mb: 2, children: tags?.length ? (_jsx(CardLabel, { type: active ? 'active' : undefined, children: _jsx(CardLabelTypography, { children: t(`main.tags.${tags[0].toLowerCase()}`) }) })) : null })) : null, _jsxs(TokenContainer, { children: [_jsx(Token, { token: token, impactToken: impactToken, step: route?.steps[0], stepVisible: !cardExpanded, isFromRoute: true, routePriceImpact: route?.priceImpact || 0 }), !defaulExpanded ? (_jsx(CardIconButton, { onClick: handleExpand, size: "small", children: cardExpanded ? (_jsx(ExpandLess, { fontSize: "inherit" })) : (_jsx(ExpandMore, { fontSize: "inherit" })) })) : null] }), _jsx(Collapse, { timeout: 225, in: cardExpanded, mountOnEnter: true, unmountOnExit: true, children: route.steps.map((step) => (_jsx(StepActions, { step: step, mt: 2 }, step.id))) }), _jsx(RouteCardEssentials, { route: route }), route?.fromChainId === MOVE_CHAIN_ID && account?.isConnected && (_jsxs(Box, { display: "flex", alignItems: "center", justifyContent: 'space-between', flex: 1, mt: 1, children: [_jsx(TokenPnLTypography, { children: "\uD83D\uDCCA PnL" }), _jsx(Box, { display: "flex", alignItems: "center", children: _jsx(Typography, { fontSize: 14, color: Number(dataPnl.pnl) === 0
                                ? 'text.primary'
                                : Number(dataPnl.pnl) < 0
                                    ? '#f05252'
                                    : '#00A878', fontWeight: 600, lineHeight: 1, marginRight: 0.6, children: Math.abs(Number(dataPnl.pnl)) < 0.1 ? (`< ${Number(dataPnl.pnl) < 0 ? '-' : ''}$0.1`) : (_jsx(_Fragment, { children: t(`format.currency`, {
                                    value: Number(dataPnl.pnl),
                                }) })) }) })] }))] }));
    return subvariant === 'refuel' || variant === 'cardless' ? (cardContent) : (_jsx(Card, { type: active ? 'selected' : 'default', selectionColor: "secondary", indented: true, ...other, children: cardContent }));
};
//# sourceMappingURL=RouteCard.js.map