import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { AccessTimeFilled, LocalGasStationRounded } from '@mui/icons-material';
import { Box, Tooltip, Typography } from '@mui/material';
import { useTranslation } from 'react-i18next';
import { getAccumulatedFeeCostsBreakdown } from '../../utils/fees.js';
import { FeeBreakdownTooltip } from '../FeeBreakdownTooltip.js';
import { IconTypography } from '../IconTypography.js';
import { TokenRate } from '../TokenRate/TokenRate.js';
import { useFieldValues } from '../../stores/form/useFieldValues.js';
import { FormKeyHelper } from '../../stores/form/types.js';
import { TON_CHAIN_ID } from '../../utils/constants.js';
export const RouteCardEssentials = ({ route, }) => {
    const { t, i18n } = useTranslation();
    const executionTimeSeconds = Math.floor(route.steps.reduce((duration, step) => duration + step.estimate.executionDuration, 0));
    const executionTimeMinutes = Math.floor(executionTimeSeconds / 60);
    const { gasCosts, feeCosts, combinedFeesUSD } = getAccumulatedFeeCostsBreakdown(route);
    const [chainId] = useFieldValues(FormKeyHelper.getChainKey('from'));
    let formatCombinedFeesUSD = combinedFeesUSD;
    if (chainId === TON_CHAIN_ID) {
        formatCombinedFeesUSD = combinedFeesUSD / 10;
    }
    return (_jsxs(Box, { display: "flex", alignItems: "center", justifyContent: 'space-between', flex: 1, mt: 2, children: [_jsx(TokenRate, { route: route }), _jsxs(Box, { display: "flex", alignItems: "center", children: [!!combinedFeesUSD && (_jsx(FeeBreakdownTooltip, { gasCosts: gasCosts, feeCosts: feeCosts, children: _jsxs(Box, { display: "flex", mr: 1.5, alignItems: "center", children: [_jsx(IconTypography, { mr: 0.5, fontSize: 16, children: _jsx(LocalGasStationRounded, { fontSize: "inherit" }) }), _jsx(Typography, { fontSize: 14, color: "text.primary", fontWeight: 600, lineHeight: 1, "data-value": formatCombinedFeesUSD, children: t(`format.currency`, {
                                        value: formatCombinedFeesUSD,
                                    }) })] }) })), _jsx(Tooltip, { title: t(`tooltip.estimatedTime`), sx: { cursor: 'help' }, children: _jsxs(Box, { display: "flex", alignItems: "center", children: [_jsx(IconTypography, { mr: 0.5, fontSize: 16, children: _jsx(AccessTimeFilled, { fontSize: "inherit" }) }), _jsx(Typography, { fontSize: 14, color: "text.primary", fontWeight: 600, lineHeight: 1, children: (executionTimeSeconds < 60
                                        ? executionTimeSeconds
                                        : executionTimeMinutes).toLocaleString(i18n.language, {
                                        style: 'unit',
                                        unit: executionTimeSeconds < 60 ? 'second' : 'minute',
                                        unitDisplay: 'narrow',
                                    }) })] }) })] })] }));
};
//# sourceMappingURL=RouteCardEssentials.js.map