import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ArrowForward, ExpandLess, ExpandMore } from '@mui/icons-material';
import { Badge, Box, Collapse, Step as MuiStep, Stepper, Typography, } from '@mui/material';
import { useState } from 'react';
import { useTranslation } from 'react-i18next';
import { formatUnits } from 'viem';
import { useAvailableChains } from '../../hooks/useAvailableChains.js';
import { LiFiToolLogo } from '../../icons/lifi.js';
import { useWidgetConfig } from '../../providers/WidgetProvider/WidgetProvider.js';
import { HiddenUI } from '../../types/widget.js';
import { formatTokenAmount } from '../../utils/format.js';
import { CardIconButton } from '../Card/CardIconButton.js';
import { SmallAvatar } from '../SmallAvatar.js';
import { StepAvatar, StepConnector, StepContent, StepLabel, StepLabelTypography, } from './StepActions.style.js';
import { StepFees } from './StepFees.js';
import { ChainId } from '../../types/base.js';
import { safeBigInt } from '../../utils/utils.js';
export const StepActions = ({ step, dense, ...other }) => {
    const { t } = useTranslation();
    const { subvariant,
    // brandingLogo
     } = useWidgetConfig();
    const [cardExpanded, setCardExpanded] = useState(false);
    const handleExpand = (e) => {
        e.stopPropagation();
        Promise.resolve().then(() => {
            setCardExpanded((expanded) => !expanded);
        });
    };
    // FIXME: step transaction request overrides step tool details, but not included step tool details
    const toolDetails = subvariant === 'custom'
        ? step?.includedSteps?.find((step) => step.tool === 'custom' && step.toolDetails.key !== 'custom')?.toolDetails || step.toolDetails
        : step.toolDetails;
    return (_jsxs(Box, { ...other, children: [_jsxs(Box, { display: "flex", alignItems: "center", children: [_jsx(Badge
                    // overlap="circular"
                    // anchorOrigin={{ vertical: 'bottom', horizontal: 'right' }}
                    // badgeContent={
                    //   <SmallAvatar src={brandingLogo ? brandingLogo : LiFiToolLogo} />
                    // }
                    , { children: _jsx(StepAvatar, { variant: "circular", src: toolDetails?.logoURI ?? LiFiToolLogo, alt: toolDetails?.name, children: toolDetails?.name?.[0] }) }), _jsxs(Box, { flex: 1, children: [_jsx(Typography, { fontSize: 18, fontWeight: 600, lineHeight: 1.3334, ml: 2, children: toolDetails?.name?.includes('LI.FI')
                                    ? toolDetails.name
                                    : t(`main.stepDetails`, {
                                        tool: toolDetails?.name,
                                    }) }), _jsx(StepFees, { ml: 2, step: step })] }), dense ? (_jsx(CardIconButton, { onClick: handleExpand, size: "small", children: cardExpanded ? (_jsx(ExpandLess, { fontSize: "inherit" })) : (_jsx(ExpandMore, { fontSize: "inherit" })) })) : null] }), dense ? (_jsx(Collapse, { timeout: 225, in: cardExpanded, mountOnEnter: true, unmountOnExit: true, children: _jsx(IncludedSteps, { step: step }) })) : (_jsx(IncludedSteps, { step: step }))] }));
};
export const IncludedSteps = ({ step }) => {
    const { t } = useTranslation();
    const { subvariant, subvariantOptions, feeConfig, hiddenUI, 
    // commissionBps,
    commissionBpsSDK, } = useWidgetConfig();
    let includedSteps = step.includedSteps;
    if (hiddenUI?.includes(HiddenUI.IntegratorStepDetails)) {
        const feeCollectionStep = includedSteps.find((step) => step.tool === 'feeCollection');
        if (feeCollectionStep) {
            includedSteps = structuredClone(includedSteps.filter((step) => step.tool !== 'feeCollection'));
            includedSteps[0].estimate.fromAmount =
                feeCollectionStep.estimate.fromAmount;
        }
    }
    // eslint-disable-next-line react/no-unstable-nested-components
    const StepIconComponent = ({ icon }) => {
        const includedStep = includedSteps?.[Number(icon) - 1];
        const feeCollectionStep = includedStep?.type === 'protocol' &&
            includedStep?.tool === 'feeCollection';
        const toolName = feeCollectionStep && feeConfig?.name
            ? feeConfig?.name
            : includedStep?.toolDetails?.name;
        const toolLogoURI = feeCollectionStep && feeConfig?.logoURI
            ? feeConfig?.logoURI
            : includedStep?.toolDetails.logoURI;
        return toolLogoURI ? (_jsx(SmallAvatar, { src: toolLogoURI, alt: toolName, sx: { width: 20, height: 20 }, children: toolName?.[0] })) : null;
    };
    return (_jsxs(Box, { mt: 1, children: [_jsx(Stepper, { orientation: "vertical", connector: _jsx(StepConnector, {}), activeStep: -1, children: (includedSteps || [])?.map((step, i, includedSteps) => (_jsxs(MuiStep, { expanded: true, children: [_jsx(StepLabel, { StepIconComponent: StepIconComponent, children: step.type === 'custom' && subvariant === 'custom' ? (_jsx(CustomStepDetailsLabel, { step: step, subvariant: subvariant, subvariantOptions: subvariantOptions })) : step.type === 'cross' ? (_jsx(BridgeStepDetailsLabel, { step: step })) : step.type === 'protocol' ? (_jsx(ProtocolStepDetailsLabel, { step: step, feeConfig: feeConfig })) : (_jsx(SwapStepDetailsLabel, { step: step })) }), _jsx(StepContent, { last: i === includedSteps.length - 1, children: _jsx(StepDetailsContent, { step: step }) })] }, step.id))) }), commissionBpsSDK && commissionBpsSDK[ChainId.MOVE] ? (_jsxs(Box, { display: "flex", justifyContent: "space-between", mt: 1, children: [_jsx(Typography, { variant: "body2", fontWeight: "500", children: "Swap Fee" }), _jsx(Typography, { variant: "body2", children: t('format.percent', {
                            value: commissionBpsSDK &&
                                commissionBpsSDK[ChainId.MOVE] &&
                                commissionBpsSDK[ChainId.MOVE] / 10000,
                        }) })] })) : null] }));
};
export const StepDetailsContent = ({ step }) => {
    const { t } = useTranslation();
    const sameTokenProtocolStep = step.action.fromToken?.chainId === step.action.toToken?.chainId &&
        step.action.fromToken?.address === step.action.toToken?.address;
    let fromAmount;
    if (sameTokenProtocolStep) {
        const estimatedFromAmount = safeBigInt(step?.estimate?.fromAmount) -
            safeBigInt(step?.estimate?.toAmount);
        fromAmount =
            estimatedFromAmount > 0n
                ? formatUnits(estimatedFromAmount, step?.action?.fromToken?.decimals || 0)
                : formatUnits(safeBigInt(step?.estimate?.fromAmount), step?.action?.fromToken?.decimals || 0);
    }
    else {
        fromAmount = formatTokenAmount(safeBigInt(step?.estimate?.fromAmount), step?.action?.fromToken?.decimals || 0);
    }
    const showToAmount = step.type !== 'custom' && step.tool !== 'custom' && !sameTokenProtocolStep;
    return (_jsxs(Typography, { fontSize: 12, lineHeight: 1, fontWeight: "500", color: "text.secondary", alignItems: "center", display: "flex", children: [!showToAmount ? (_jsxs(_Fragment, { children: [formatUnits(safeBigInt(step?.estimate?.fromAmount), step?.action?.fromToken?.decimals || 0), ' ', step?.action?.fromToken?.symbol, ' - '] })) : null, t('format.number', {
                value: fromAmount,
            }), ' ', step?.action?.fromToken?.symbol, showToAmount ? (_jsxs(_Fragment, { children: [_jsx(ArrowForward, { sx: { fontSize: 18, paddingX: 0.5, height: 12 } }), t('format.number', {
                        value: formatTokenAmount(safeBigInt(step?.execution?.toAmount ?? step?.estimate?.toAmount), step.execution?.toToken?.decimals ??
                            (step.action.toToken?.decimals || 0)),
                    }), ' ', step.execution?.toToken?.symbol ?? step.action.toToken?.symbol] })) : (` (${t('format.currency', {
                value: parseFloat(fromAmount || '0') *
                    parseFloat(step?.action?.fromToken?.priceUSD || '0'),
            })})`)] }));
};
export const CustomStepDetailsLabel = ({ step, subvariant, subvariantOptions, }) => {
    const { t } = useTranslation();
    if (!subvariant) {
        return null;
    }
    // FIXME: step transaction request overrides step tool details, but not included step tool details
    const toolDetails = subvariant === 'custom' &&
        step.includedSteps?.length > 0
        ? step.includedSteps.find((step) => step.tool === 'custom' && step.toolDetails.key !== 'custom')?.toolDetails || step.toolDetails
        : step.toolDetails;
    const stepDetailsKey = (subvariant === 'custom' && subvariantOptions?.custom) || 'checkout';
    return (_jsx(StepLabelTypography, { children: t(`main.${stepDetailsKey}StepDetails`, {
            tool: toolDetails.name,
        }) }));
};
export const BridgeStepDetailsLabel = ({ step }) => {
    const { t } = useTranslation();
    const { getChainById } = useAvailableChains();
    return (_jsx(StepLabelTypography, { children: t('main.bridgeStepDetails', {
            from: getChainById(step.action.fromChainId)?.name,
            to: getChainById(step.action.toChainId)?.name,
            tool: step.toolDetails.name,
        }) }));
};
export const SwapStepDetailsLabel = ({ step }) => {
    const { t } = useTranslation();
    const { getChainById } = useAvailableChains();
    return (_jsx(StepLabelTypography, { children: t('main.swapStepDetails', {
            chain: getChainById(step.action.fromChainId)?.name,
            tool: step.toolDetails.name,
        }) }));
};
export const ProtocolStepDetailsLabel = ({ step, feeConfig }) => {
    const { t } = useTranslation();
    return (_jsx(StepLabelTypography, { children: step.toolDetails.key === 'feeCollection'
            ? feeConfig?.name
                ? t('main.fees.integrator', { tool: feeConfig.name })
                : t('main.fees.defaultIntegrator')
            : step.toolDetails.key === 'lifuelProtocol'
                ? t('main.refuelStepDetails', {
                    tool: step.toolDetails.name,
                })
                : step.toolDetails.name }));
};
//# sourceMappingURL=StepActions.js.map