import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ExpandLess, ExpandMore, LocalGasStationRounded, } from '@mui/icons-material';
import { Box, Collapse, Tooltip, Typography } from '@mui/material';
import { useState } from 'react';
import { useTranslation } from 'react-i18next';
import { formatUnits } from 'viem';
import { useWidgetConfig } from '../providers/WidgetProvider/WidgetProvider.js';
import { isRouteDone } from '../stores/routes/utils.js';
import { getAccumulatedFeeCostsBreakdown } from '../utils/fees.js';
import { formatTokenAmount, formatTokenPrice } from '../utils/format.js';
import { Card } from './Card/Card.js';
import { CardIconButton } from './Card/CardIconButton.js';
import { FeeBreakdownTooltip } from './FeeBreakdownTooltip.js';
import { IconTypography } from './IconTypography.js';
import { TokenRate } from './TokenRate/TokenRate.js';
import { TON_CHAIN_ID } from '../utils/constants.js';
import { safeBigInt } from '../utils/utils.js';
export const TransactionDetails = ({ route, ...props }) => {
    const { t } = useTranslation();
    const { feeConfig } = useWidgetConfig();
    const [cardExpanded, setCardExpanded] = useState(false);
    // const toggleCard = () => {
    //   setCardExpanded((cardExpanded) => !cardExpanded);
    // };
    const { gasCosts, feeCosts, gasCostUSD, feeCostUSD, combinedFeesUSD } = getAccumulatedFeeCostsBreakdown(route);
    const fromTokenAmount = formatTokenAmount(safeBigInt(route?.fromAmount), route?.fromToken?.decimals || 0);
    const fromTokenPrice = formatTokenPrice(fromTokenAmount, route.fromToken.priceUSD);
    const toTokenAmount = formatTokenAmount(safeBigInt(route?.toAmount), route?.toToken?.decimals || 0);
    const toTokenPrice = formatTokenPrice(toTokenAmount, route?.toToken?.priceUSD) || 0.01;
    const priceImpact = toTokenPrice / fromTokenPrice - 1;
    const feeCollectionStep = route?.steps?.[0]?.includedSteps?.find((includedStep) => includedStep.tool === 'feeCollection');
    let formatCombinedFeesUSD = combinedFeesUSD;
    let formatGasCostUSD = gasCostUSD;
    let formatFeeCostUSD = feeCostUSD;
    if (route?.fromChainId === TON_CHAIN_ID) {
        formatCombinedFeesUSD = combinedFeesUSD / 10;
        formatGasCostUSD = gasCostUSD / 10;
        formatFeeCostUSD = feeCostUSD / 10;
    }
    let feeAmountUSD = 0;
    if (feeCollectionStep) {
        const estimatedFromAmount = safeBigInt(feeCollectionStep.estimate.fromAmount) -
            safeBigInt(feeCollectionStep.estimate.toAmount);
        const feeAmount = formatUnits(estimatedFromAmount, feeCollectionStep.action.fromToken.decimals);
        feeAmountUSD =
            parseFloat(feeAmount) *
                parseFloat(feeCollectionStep.action.fromToken.priceUSD || '0');
    }
    // Move state updates out of render
    const handleCardToggle = () => {
        Promise.resolve().then(() => {
            setCardExpanded(!cardExpanded);
        });
    };
    const showIntegratorFeeCollectionDetails = feeAmountUSD || Number.isFinite(feeConfig?.fee);
    return (_jsxs(Card, { selectionColor: "secondary", ...props, children: [_jsxs(Box, { display: "flex", alignItems: "center", px: 2, py: 1.75, children: [_jsx(Box, { display: "flex", flex: 1, alignItems: "center", justifyContent: "left", children: _jsx(TokenRate, { route: route }) }), !!formatCombinedFeesUSD && (_jsx(Collapse, { timeout: 100, in: !cardExpanded, mountOnEnter: true, children: _jsx(FeeBreakdownTooltip, { gasCosts: gasCosts, feeCosts: feeCosts, children: _jsxs(Box, { display: "flex", alignItems: "center", onClick: handleCardToggle, role: "button", sx: { cursor: 'pointer' }, px: 1, children: [_jsx(IconTypography, { mr: 0.5, fontSize: 16, children: _jsx(LocalGasStationRounded, { fontSize: "inherit" }) }), _jsx(Typography, { fontSize: 14, color: "text.primary", fontWeight: "600", lineHeight: 1.429, "data-value": formatCombinedFeesUSD, children: t(`format.currency`, { value: formatCombinedFeesUSD }) })] }) }) })), _jsx(CardIconButton, { onClick: handleCardToggle, size: "small", children: cardExpanded ? (_jsx(ExpandLess, { fontSize: "inherit" })) : (_jsx(ExpandMore, { fontSize: "inherit" })) })] }), _jsx(Collapse, { timeout: 225, in: cardExpanded, mountOnEnter: true, children: _jsxs(Box, { px: 2, pb: 2, children: [_jsxs(Box, { display: "flex", justifyContent: "space-between", mb: 0.5, children: [_jsx(Typography, { variant: "body2", children: t('main.fees.network') }), _jsx(FeeBreakdownTooltip, { gasCosts: gasCosts, children: _jsx(Typography, { variant: "body2", children: t(`format.currency`, {
                                            value: formatGasCostUSD,
                                        }) }) })] }), feeCosts.length ? (_jsxs(Box, { display: "flex", justifyContent: "space-between", mb: 0.5, children: [_jsx(Typography, { variant: "body2", children: t('main.fees.provider') }), _jsx(FeeBreakdownTooltip, { feeCosts: feeCosts, children: _jsx(Typography, { variant: "body2", children: t(`format.currency`, {
                                            value: formatFeeCostUSD,
                                        }) }) })] })) : null, showIntegratorFeeCollectionDetails ? (_jsxs(Box, { display: "flex", justifyContent: "space-between", mb: 0.5, children: [_jsx(Typography, { variant: "body2", children: feeConfig?.name
                                        ? t('main.fees.integrator', { tool: feeConfig.name })
                                        : t('main.fees.defaultIntegrator') }), feeConfig?.name ? (_jsx(Tooltip, { title: t('tooltip.feeCollection', { tool: feeConfig.name }), sx: { cursor: 'help' }, children: _jsx(Typography, { variant: "body2", children: t(`format.currency`, {
                                            value: feeAmountUSD,
                                        }) }) })) : (_jsx(Typography, { variant: "body2", children: t(`format.currency`, {
                                        value: feeAmountUSD,
                                    }) }))] })) : null, _jsxs(Box, { display: "flex", justifyContent: "space-between", mb: 0.5, children: [_jsx(Typography, { variant: "body2", children: t('main.priceImpact') }), _jsx(Tooltip, { title: t('tooltip.priceImpact'), sx: { cursor: 'help' }, children: _jsx(Typography, { variant: "body2", children: t('format.percent', { value: priceImpact }) }) })] }), !isRouteDone(route) ? (_jsxs(_Fragment, { children: [_jsxs(Box, { display: "flex", justifyContent: "space-between", mb: 0.5, children: [_jsx(Typography, { variant: "body2", children: t('main.maxSlippage') }), _jsx(Tooltip, { title: t('tooltip.slippage'), sx: { cursor: 'help' }, children: _jsx(Typography, { variant: "body2", children: t('format.percent', {
                                                    value: route.steps[0].action.slippage,
                                                }) }) })] }), _jsxs(Box, { display: "flex", justifyContent: "space-between", children: [_jsx(Typography, { variant: "body2", children: t('main.minReceived') }), _jsx(Tooltip, { title: t('tooltip.minReceived'), sx: { cursor: 'help' }, children: _jsxs(Typography, { variant: "body2", children: [t('format.number', {
                                                        value: formatTokenAmount(safeBigInt(route?.toAmountMin), route?.toToken?.decimals || 0),
                                                    }), ' ', route?.toToken?.symbol] }) })] })] })) : null] }) })] }));
};
//# sourceMappingURL=TransactionDetails.js.map