import { ChainType } from '../../utils/chainType.js';
import { isAddress } from './isAddress.js';
import { getEclipseBalance } from './getEclipseBalance.js';
import { useEclipseAddress } from './getEclipseAddress.js';
import { EclipseStepExecutor } from './EclipseStepExecutor.js';
export function Eclipse(options) {
    const _options = options ?? {};
    return {
        get type() {
            return ChainType.ECLIPSE;
        },
        isAddress,
        resolveAddress: useEclipseAddress,
        getBalance: getEclipseBalance,
        async getStepExecutor(options) {
            if (!_options.getWalletAdapter) {
                throw new Error(`getWalletAdapter is not provided.`);
            }
            const walletAdapter = await _options.getWalletAdapter();
            const executor = new EclipseStepExecutor({
                routeId: options.routeId,
                walletAdapter: walletAdapter,
                executionOptions: {
                    ...options.executionOptions,
                    slippage: _options.slippage,
                },
            });
            return executor;
        },
        setOptions(options) {
            Object.assign(_options, options);
        },
    };
}
//# sourceMappingURL=Eclipse.js.map