import { ChainType } from '../../utils/chainType.js';
import { isAddress } from './isAddress.js';
import { getTONBalance } from './getTONBalance.js';
import { getTONAddress } from './getTONAddress.js';
import { TVMStepExecutor } from './TVMStepExecutor.js';
export function TVM(options) {
    const _options = options ?? {};
    return {
        get type() {
            return ChainType.TVM;
        },
        isAddress,
        resolveAddress: getTONAddress,
        getBalance: getTONBalance,
        async getStepExecutor(options) {
            if (!_options.getWalletAdapter) {
                throw new Error(`getWalletAdapter is not provided.`);
            }
            const walletAdapter = await _options.getWalletAdapter();
            const executor = new TVMStepExecutor({
                routeId: options.routeId,
                walletAdapter: walletAdapter,
                executionOptions: {
                    ...options.executionOptions,
                    slippage: _options.slippage,
                },
            });
            return executor;
        },
        setOptions(options) {
            Object.assign(_options, options);
        },
    };
}
//# sourceMappingURL=TVM.js.map