import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Button, DialogActions, DialogContent, DialogContentText, List, } from '@mui/material';
import { useCallback, useState } from 'react';
import { useTranslation } from 'react-i18next';
import { useAccount as useWagmiAccount } from 'wagmi';
import { Dialog } from '../../components/Dialog.js';
import { PageContainer } from '../../components/PageContainer.js';
import { useHeader } from '../../hooks/useHeader.js';
import { useWallets } from '../../hooks/useWallets.js';
import { useWidgetConfig } from '../../providers/WidgetProvider/WidgetProvider.js';
import { EVMListItemButton } from './EVMListItemButton.js';
import { SVMListItemButton } from './SVMListItemButton.js';
import { TVMListItemButton } from './TVMListItemButton.js';
import { MVMListItemButton } from './MVMListItemButton.js';
export const SelectWalletPage = () => {
    const { t } = useTranslation();
    const { chains, walletConfig } = useWidgetConfig();
    const account = useWagmiAccount();
    const [walletIdentity, setWalletIdentity] = useState({ show: false });
    useHeader(t(`header.selectWallet`));
    const closeDialog = () => {
        setWalletIdentity((state) => ({
            ...state,
            show: false,
        }));
    };
    const handleNotInstalled = useCallback(async (connector) => {
        setWalletIdentity({
            show: true,
            connector,
        });
    }, []);
    const wallets = useWallets(walletConfig, chains);
    const renderWallets = () => {
        return wallets?.map((connector) => {
            if (connector.uid) {
                return (_jsx(EVMListItemButton, { connector: connector, connectedConnector: account.connector, onNotInstalled: handleNotInstalled }, connector.uid));
            }
            // @ts-ignore
            if (connector.type === 'TVM') {
                return (_jsx(TVMListItemButton, { wallet: connector }, connector.name));
            }
            // @ts-ignore
            if (connector.type === 'MVM') {
                return (_jsx(MVMListItemButton, { walletProps: connector }, connector.name));
            }
            if (connector.adapter) {
                return (_jsx(SVMListItemButton, { wallet: connector }, connector.adapter.name));
            }
            return null;
        });
    };
    return (_jsxs(PageContainer, { disableGutters: true, children: [_jsx(List, { sx: {
                    paddingTop: 0,
                    paddingLeft: 1.5,
                    paddingRight: 1.5,
                    paddingBottom: 1.5,
                }, children: renderWallets() }), _jsxs(Dialog, { open: walletIdentity.show, onClose: closeDialog, children: [_jsx(DialogContent, { children: _jsx(DialogContentText, { children: t('wallet.extensionNotFound', {
                                name: walletIdentity.connector?.name,
                            }) }) }), _jsx(DialogActions, { children: _jsx(Button, { variant: "contained", onClick: closeDialog, autoFocus: true, children: t('button.ok') }) })] })] }));
};
//# sourceMappingURL=SelectWalletPage.js.map