import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { BoltRounded, Info, Shield, WarningRounded } from '@mui/icons-material';
import { Box, Switch, Typography, Tooltip } from '@mui/material';
import { useState, useEffect } from 'react';
// import { useTranslation } from 'react-i18next';
import { useSettingMonitor } from '../../../hooks/useSettingMonitor.js';
import { useSettings } from '../../../stores/settings/useSettings.js';
import { useSettingsStore } from '../../../stores/settings/useSettingsStore.js';
import { BadgedValue } from '../SettingsCard/BadgedValue.js';
import { SettingCardExpandable } from '../SettingsCard/SettingCardExpandable.js';
// @ts-ignore
import { useWallet } from '@suiet/wallet-kit';
import { SuiClient } from '@mysten/sui/client';
import { GasInput, GasInputContainer, GasInputLabel, GasValueDisplay, ModeToggleButton, PoweredByContainer, SettingsFieldSet, WarningContainer, } from './ShioSettings.style.js';
import { MaxButton } from '../../../components/AmountInput/AmountInputAdornment.style.js';
import { useRoutes } from '../../../hooks/useRoutes.js';
export const ShioSettings = () => {
    // const { t } = useTranslation();
    const setValue = useSettingsStore((state) => state.setValue);
    const { isShioSettingsChanged } = useSettingMonitor();
    const { transactionMode, customGasPrice, maxGasCap, mevProtection } = useSettings([
        'transactionMode',
        'customGasPrice',
        'maxGasCap',
        'mevProtection',
    ]);
    const { routes, refetch } = useRoutes();
    const currentRoute = routes?.[0];
    const wallet = useWallet();
    const [walletBalance, setWalletBalance] = useState('0');
    const refetchRoutes = () => {
        if (currentRoute) {
            refetch();
        }
    };
    useEffect(() => {
        const fetchBalance = async () => {
            if (wallet.address) {
                try {
                    const client = new SuiClient({
                        url: 'https://fullnode.mainnet.sui.io',
                    });
                    const balance = await client.getBalance({
                        owner: wallet.address,
                        coinType: '0x2::sui::SUI',
                    });
                    setWalletBalance((Number(balance.totalBalance) * 0.000000001).toFixed(9));
                }
                catch (error) {
                    console.error('Error fetching balance:', error);
                    setWalletBalance('0');
                }
            }
        };
        fetchBalance();
    }, [wallet.address]);
    const handleModeChange = (mode) => {
        setValue('transactionMode', mode);
        if (mode === 'fast') {
            setValue('mevProtection', true);
        }
        if (mode === 'default') {
            setValue('maxGasCap', '0.5');
            setValue('customGasPrice', '1500');
        }
    };
    const handleGasPriceChange = (event) => {
        const value = event.target.value;
        if (value && (Number(value) <= 0 || value.startsWith('-'))) {
            return;
        }
        setValue('customGasPrice', value);
    };
    const handleMaxCapChange = (event) => {
        const value = event.target.value;
        if (!value) {
            setValue('maxGasCap', '');
            return;
        }
        if (value !== '-' && value !== '.') {
            const numValue = Number(value);
            if (isNaN(numValue)) {
                return;
            }
            if (value.startsWith('-')) {
                return;
            }
            if (numValue > Number(walletBalance)) {
                return;
            }
        }
        setValue('maxGasCap', value);
    };
    const handleMEVProtectionChange = (event) => {
        setValue('mevProtection', event.target.checked);
        refetchRoutes();
    };
    const handleCalculateGasPrice = (mistValue) => {
        if (!mistValue || isNaN(Number(mistValue))) {
            return '0';
        }
        return (Number(mistValue) * 0.000000001).toFixed(9);
    };
    const handleSetHalfBalance = () => {
        const halfBalance = (Number(walletBalance) / 2).toString();
        setValue('maxGasCap', halfBalance);
    };
    const handleSetFullBalance = () => {
        setValue('maxGasCap', walletBalance);
    };
    const isGasPriceOutsideRecommendedLimits = Number(customGasPrice) < 750;
    const isGasPriceInvalid = customGasPrice !== undefined &&
        (Number(customGasPrice) <= 0 || customGasPrice.startsWith('-'));
    const isMaxGasCapInvalid = maxGasCap !== undefined &&
        maxGasCap !== '' &&
        (Number(maxGasCap) <= 0 || maxGasCap.startsWith('-'));
    return (_jsx(SettingCardExpandable, { value: _jsx(BadgedValue, { badgeColor: "info", showBadge: isShioSettingsChanged, children: transactionMode === 'fast' ? 'Fast Mode' : 'Default Mode' }), icon: _jsx(BoltRounded, {}), title: "Transaction Mode", children: _jsxs(Box, { mt: 1.5, children: [_jsxs(SettingsFieldSet, { children: [_jsx(ModeToggleButton, { selected: transactionMode === 'default', onClick: () => {
                                handleModeChange('default');
                                refetchRoutes();
                            }, disableRipple: true, children: "Default Mode" }), _jsxs(ModeToggleButton, { selected: transactionMode === 'fast', onClick: () => {
                                handleModeChange('fast');
                                refetchRoutes();
                            }, disableRipple: true, children: [_jsx(BoltRounded, { sx: { mr: 0.5 } }), "Fast Mode"] })] }), transactionMode === 'default' ? (_jsx(Typography, { variant: "body2", color: "text.secondary", mt: 2, children: "Standard gas price based on real-time network conditions" })) : (_jsxs(_Fragment, { children: [_jsx(Typography, { variant: "body2", color: "text.secondary", mt: 2, children: "Land your transaction earlier and avoid congestion with a higher gas price. MEV protection is on by default in Fast Mode." }), _jsxs(GasInputContainer, { children: [_jsx(GasInputLabel, { children: _jsxs(Box, { children: [_jsx(Typography, { children: "Custom Gas Price" }), _jsx(Tooltip, { title: "The total gas depends on the gas price and actual gas units consumed.", arrow: true, children: _jsx(Info, { sx: { fontSize: 16, color: 'text.secondary' } }) })] }) }), _jsxs(Box, { position: "relative", flex: 1, children: [_jsx(Box, { position: "absolute", left: 12, top: "50%", sx: {
                                                transform: 'translateY(-50%)',
                                                color: 'text.secondary',
                                                fontSize: '0.875rem',
                                                pointerEvents: 'none',
                                                zIndex: 1,
                                            }, children: "MIST" }), _jsx(GasInput, { value: customGasPrice, onChange: handleGasPriceChange, placeholder: "Enter Gas Price", error: isGasPriceInvalid, sx: { paddingLeft: '44px', width: '100%' }, inputProps: {
                                                inputMode: 'decimal',
                                            } })] }), _jsxs(GasValueDisplay, { children: [_jsxs("span", { children: [_jsx("strong", { children: customGasPrice || '0' }), " MIST"] }), "=", _jsxs("span", { children: [_jsx("strong", { children: handleCalculateGasPrice(customGasPrice) }), " SUI"] })] }), isGasPriceInvalid && (_jsx(Typography, { variant: "caption", color: "error", children: "Gas price must be greater than 0" }))] }), _jsxs(GasInputContainer, { children: [_jsxs(GasInputLabel, { children: [_jsxs(Box, { children: [_jsx(Typography, { children: "Max Gas Cap" }), _jsx(Tooltip, { title: "Set a max cap for your gas to prevent overpaying", arrow: true, children: _jsx(Info, { sx: { fontSize: 16, color: 'text.secondary' } }) })] }), _jsxs(GasValueDisplay, { children: [_jsx(MaxButton, { onClick: handleSetHalfBalance, children: "half" }), " /", _jsx("span", { style: { cursor: 'pointer', textDecoration: 'underline' }, onClick: handleSetFullBalance, children: _jsx("strong", { children: walletBalance }) }), "SUI"] })] }), _jsxs(Box, { position: "relative", flex: 1, children: [_jsx(Box, { position: "absolute", left: 12, top: "50%", sx: {
                                                transform: 'translateY(-50%)',
                                                color: 'text.secondary',
                                                fontSize: '0.875rem',
                                                pointerEvents: 'none',
                                                zIndex: 1,
                                            }, children: "SUI" }), _jsx(GasInput, { value: maxGasCap, onChange: handleMaxCapChange, placeholder: "Enter Max Gas Cap", error: isMaxGasCapInvalid, sx: { paddingLeft: '44px', width: '100%' }, inputProps: {
                                                inputMode: 'decimal',
                                            } })] }), isMaxGasCapInvalid && (_jsx(Typography, { variant: "caption", color: "error", children: "Max gas cap must be greater than 0" }))] }), isGasPriceOutsideRecommendedLimits && (_jsxs(WarningContainer, { children: [_jsx(WarningRounded, { color: "warning" }), _jsx(Typography, { variant: "body2", children: "Gas price is outside recommended limits" })] }))] })), _jsxs(Box, { mt: 2, display: "flex", justifyContent: "space-between", alignItems: "center", children: [_jsxs(Box, { display: "flex", alignItems: "center", gap: 1, children: [_jsx(Shield, {}), _jsx(Typography, { children: "MEV Protection" }), _jsx(Tooltip, { title: "By enabling this, your txn will be submitted via 3rd party MEV service provider. MEV value retained will be redistributed to all users who successfully execute their trades with Shio through its point campaign.", arrow: true, children: _jsx(Info, { sx: { fontSize: 16, color: 'text.secondary' } }) })] }), _jsx(Switch, { checked: transactionMode === 'fast' ? true : mevProtection, onChange: handleMEVProtectionChange, disabled: transactionMode === 'fast', color: "primary" })] }), _jsxs(PoweredByContainer, { children: ["Powered by", _jsxs("div", { className: "logo-container", children: [_jsx("img", { src: "https://docs.getshio.com/~gitbook/image?url=https%3A%2F%2F3721569642-files.gitbook.io%2F%7E%2Ffiles%2Fv0%2Fb%2Fgitbook-x-prod.appspot.com%2Fo%2Forganizations%252FmKbUal37gqZi7laa9OvC%252Fsites%252Fsite_d1fYx%252Ficon%252Fyi0vEFYZ9Lv1w4MN8qR3%252FPasted%2520Graphic%25204.jpg%3Falt%3Dmedia%26token%3D046b9caa-31c1-481b-a63b-8aa59b0c8cdf&width=32&dpr=2&quality=100&sign=83ecf93a&sv=2", alt: "Shio", width: 16, height: 16 }), _jsx("span", { className: "shio-text", children: "Shio" })] })] })] }) }));
};
//# sourceMappingURL=ShioSettings.js.map