import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useState, useMemo, } from 'react';
import { 
// @ts-ignore
WalletProvider, 
// @ts-ignore
PhantomWallet, 
// @ts-ignore
SlushWallet, 
// @ts-ignore
SuietWallet, 
// @ts-ignore
ConnectModal, 
// @ts-ignore
defineSlushWallet, 
// @ts-ignore
useWallet, } from '@suiet/wallet-kit';
import { ShioFastRpcUrl } from 'shio-fast-sdk';
import { MVM_RPC_URL, SHIO_DEFAULT_RPC_URL } from '../../../utils/mvm.js';
import { useSettings } from '../../../stores/settings/useSettings.js';
const slushWallet = defineSlushWallet({
    appName: 'Nimbus',
    network: 'mainnet',
});
export const MVMBaseContext = createContext({
    moveWalletInstance: null,
    isConnected: false,
});
export const useMove = () => useContext(MVMBaseContext);
export const MVMBaseProvider = ({ children }) => {
    const wallet = useWallet();
    const [showModal, setShowModal] = useState(false);
    const [isConnected, setIsConnected] = useState(false);
    useEffect(() => {
        const timer = setTimeout(() => {
            setIsConnected(false);
        }, 2000); // 2s
        return () => clearTimeout(timer);
    }, [isConnected]);
    const onConnectSuccess = (msg) => {
        // eslint-disable-next-line no-console
        console.log('Success connect: ', msg);
        setShowModal(false);
        setIsConnected(true);
    };
    const onConnectError = (msg) => {
        // eslint-disable-next-line no-console
        console.error('Error connect', msg);
        setIsConnected(false);
    };
    const handleSetState = () => {
        wallet.toggleSelect = () => {
            setShowModal(!showModal);
        };
    };
    useEffect(() => {
        handleSetState();
        // eslint-disable-next-line  react-hooks/exhaustive-deps
    }, [wallet]);
    const { mevProtection, transactionMode } = useSettings([
        'mevProtection',
        'transactionMode',
    ]);
    const chains = useMemo(() => {
        const rpcUrl = !mevProtection
            ? MVM_RPC_URL
            : transactionMode === 'default'
                ? SHIO_DEFAULT_RPC_URL
                : ShioFastRpcUrl;
        return [
            {
                id: 'sui:mainnet',
                name: 'Mainnet',
                rpcUrl: rpcUrl,
                network: 'mainnet',
                chainId: 'sui:mainnet',
            },
        ];
    }, [mevProtection, transactionMode]);
    return (_jsx(WalletProvider, { defaultWallets: [SlushWallet, slushWallet, SuietWallet, PhantomWallet], autoConnect: true, chains: chains, children: _jsxs(MVMBaseContext.Provider, { value: {
                moveWalletInstance: wallet,
                isConnected,
            }, children: [children, _jsx(ConnectModal, { open: showModal, onOpenChange: (open) => setShowModal(open), onConnectSuccess: onConnectSuccess, onConnectError: onConnectError })] }) }, chains[0].rpcUrl));
};
//# sourceMappingURL=MVMBaseProvider.js.map