import { EVM, config } from '@lifi/sdk';
import { useWallet as useSolanaWallet } from '@solana/wallet-adapter-react';
import { getWalletClient, switchChain } from '@wagmi/core';
import { useEffect } from 'react';
import { useConfig } from 'wagmi';
import { useWidgetConfig } from '../WidgetProvider/WidgetProvider.js';
import { ChainType } from '../../utils/chainType.js';
import { TVM } from '../../core/TVM/TVM.js';
import { MVM } from '../../core/MVM/MVM.js';
import { Eclipse } from '../../core/Eclipse/Eclipse.js';
import { Solana } from '../../core/Solana/Solana.js';
import { useTon } from './TVM/TVMBaseProvider.js';
// @ts-ignore
import { useWallet } from '@suiet/wallet-kit';
import { useSettings } from '../../stores/settings/useSettings.js';
export const SDKProviders = () => {
    const { sdkConfig, chains } = useWidgetConfig();
    const { wallet } = useSolanaWallet();
    const wagmiConfig = useConfig();
    const { tonConnectUI } = useTon();
    const suiWalletInstance = useWallet();
    const { slippage, mevProtection, transactionMode, customGasPrice, maxGasCap, } = useSettings([
        'slippage',
        'mevProtection',
        'transactionMode',
        'customGasPrice',
        'maxGasCap',
    ]);
    useEffect(() => {
        // Configure SDK Providers
        const providers = [];
        const hasConfiguredEVMProvider = sdkConfig?.providers?.some((provider) => provider.type === ChainType.EVM);
        if (!hasConfiguredEVMProvider &&
            chains?.types?.allow?.includes(ChainType.EVM)) {
            providers.push(EVM({
                getWalletClient: () => getWalletClient(wagmiConfig),
                switchChain: async (chainId) => {
                    const chain = await switchChain(wagmiConfig, { chainId });
                    return getWalletClient(wagmiConfig, { chainId: chain.id });
                },
            }));
        }
        // push TVM provider here
        if (chains?.types?.allow?.includes(ChainType.TVM)) {
            providers.push(TVM({
                async getWalletAdapter() {
                    return tonConnectUI;
                },
                slippage,
            }));
        }
        // push MVM provider here
        if (chains?.types?.allow?.includes(ChainType.MVM)) {
            providers.push(MVM({
                async getWalletAdapter() {
                    return suiWalletInstance;
                },
                slippage,
                mevProtection,
                transactionMode,
                customGasPrice,
                maxGasCap,
            }));
        }
        // push Eclipse provider here
        if (chains?.types?.allow?.includes(ChainType.ECLIPSE)) {
            providers.push(Eclipse({
                async getWalletAdapter() {
                    return wallet?.adapter;
                },
                slippage,
            }));
        }
        // push Solana provider here
        const hasConfiguredSVMProvider = sdkConfig?.providers?.some((provider) => provider.type === ChainType.SVM);
        if (!hasConfiguredSVMProvider &&
            chains?.types?.allow?.includes(ChainType.SVM)) {
            providers.push(Solana({
                async getWalletAdapter() {
                    return wallet?.adapter;
                },
            }));
        }
        if (sdkConfig?.providers?.length) {
            providers.push(...sdkConfig?.providers);
        }
        config.setProviders(providers);
    }, [
        chains,
        sdkConfig?.providers,
        wagmiConfig,
        wallet?.adapter,
        sdkConfig,
        tonConnectUI,
        suiWalletInstance,
        slippage,
        mevProtection,
        transactionMode,
        customGasPrice,
        maxGasCap,
    ]);
    return null;
};
//# sourceMappingURL=SDKProviders.js.map