import { Aftermath } from 'aftermath-ts-sdk';
import { v4 as uuidv4 } from 'uuid';
import { flatten } from 'lodash';
import { handleFormatValue, mappingSuiToken, MOVE_DEX_INFO, retryOperation, } from '../utils.js';
import { ChainId } from '../../../types/base.js';
export const getRoutesAftermath = async (params) => {
    try {
        const afSdk = new Aftermath('MAINNET');
        await afSdk.init();
        const aftermathRouter = afSdk.Router();
        const router = await retryOperation(async () => {
            return await aftermathRouter
                .getCompleteTradeRouteGivenAmountIn({
                coinInType: params.fromToken,
                coinOutType: params.toToken,
                coinInAmount: BigInt(params?.fromAmount || 0),
            })
                .catch((e) => {
                console.error('>>> e', e);
                throw new Error('Not found any routes from Aftermath');
            });
        });
        if (params.isBuildTx && router) {
            try {
                const tradeTx = await retryOperation(async () => {
                    return await aftermathRouter.getTransactionForCompleteTradeRoute({
                        walletAddress: params.senderAddress || '',
                        completeRoute: router,
                        slippage: Number(params.slippage || 0.01),
                    });
                });
                return tradeTx;
            }
            catch (e) {
                console.error('>>> e', e);
                throw new Error('Not build tx from Aftermath');
            }
        }
        return router;
    }
    catch (e) {
        console.error(e);
    }
};
export const formatRoutesAftermath = (aftermathRoutes, params) => {
    const aftermathInputAmount = BigInt(aftermathRoutes?.value?.coinIn?.amount || 0);
    const aftermathOutputAmount = BigInt(aftermathRoutes?.value?.coinOut?.amount || 0);
    const aftermathFromAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, aftermathInputAmount, aftermathOutputAmount).fromValue;
    const aftermathToAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, aftermathInputAmount, aftermathOutputAmount).toValue;
    const formatListAftermathRoute = aftermathRoutes?.value?.routes?.map((item) => item.paths);
    const aftermathPriceImpact = (aftermathToAmountUSD - aftermathFromAmountUSD) / aftermathFromAmountUSD;
    const formatAftermathRouteSteps = flatten(formatListAftermathRoute)?.map((node) => {
        return {
            id: uuidv4(),
            type: 'swap',
            action: {
                fromChainId: ChainId.MOVE,
                fromAmount: node.coinIn.amount,
                fromToken: params.tokens?.find((t) => {
                    return mappingSuiToken(node?.coinIn?.type) === t.address;
                }),
                toChainId: ChainId.MOVE,
                toToken: params.tokens?.find((t) => {
                    return mappingSuiToken(node?.coinOut?.type) === t.address;
                }),
                slippage: params.options?.slippage,
                fromAddress: params.fromAddress,
            },
            estimate: {
                tool: node.protocolName.toUpperCase() || 'aftermath pool',
                fromAmount: node.coinIn.amount,
                toAmount: node.coinOut.amount,
                toAmountMin: node.coinOut.amount,
                approvalAddress: '',
                executionDuration: 1,
                feeCosts: [],
            },
            tool: node.protocolName.toUpperCase() || 'aftermath pool',
            toolDetails: {
                key: node.protocolName.toUpperCase() || 'aftermath pool',
                name: MOVE_DEX_INFO[node.protocolName.toUpperCase()]?.name ||
                    node.protocolName.toUpperCase() ||
                    'aftermath pool',
                logoURI: MOVE_DEX_INFO[node.protocolName.toUpperCase()]?.image || 'https://cryptologos.cc/logos/sui-sui-logo.svg?v=035',
            },
        };
    });
    return {
        id: uuidv4(),
        fromToken: params.fromToken,
        toToken: params.toToken,
        fromAmount: aftermathInputAmount,
        toAmount: aftermathOutputAmount,
        fromAmountUSD: aftermathFromAmountUSD,
        toAmountUSD: aftermathToAmountUSD,
        fromChainId: ChainId.MOVE,
        toChainId: ChainId.MOVE,
        toAmountMin: aftermathOutputAmount,
        gasCostUSD: 0,
        steps: [
            {
                type: 'aftermath',
                id: uuidv4(),
                tool: 'aftermath',
                toolDetails: {
                    key: 'aftermath',
                    name: 'Aftermath',
                    logoURI: 'https://strapi-dev.scand.app/uploads/Aftermath_Finance_Logo_417d1ae98e.jpg',
                },
                action: {
                    fromToken: params.fromToken,
                    fromAmount: aftermathInputAmount,
                    toToken: params.toToken,
                    fromChainId: ChainId.MOVE,
                    toChainId: ChainId.MOVE,
                    slippage: params.options?.slippage,
                    fromAddress: params.fromAddress,
                    toAddress: params.toAddress || params.fromAddress,
                },
                estimate: {
                    tool: 'aftermath',
                    approvalAddress: '',
                    toAmountMin: aftermathOutputAmount,
                    toAmount: aftermathOutputAmount,
                    fromAmount: aftermathInputAmount,
                    feeCosts: [],
                    // gasCosts: [],
                    executionDuration: 1,
                    fromAmountUSD: aftermathFromAmountUSD,
                    toAmountUSD: aftermathToAmountUSD,
                },
                includedSteps: formatAftermathRouteSteps,
                integrator: 'aftermath',
                execution: {
                    status: 'PENDING',
                    process: [],
                },
            },
        ],
        path: [],
        insurance: {},
        priceImpact: aftermathPriceImpact || 0,
    };
};
//# sourceMappingURL=index.js.map