import { HopApi } from '@hop.ag/sdk';
import { MVM_RPC_URL } from '../../../utils/mvm.js';
import { v4 as uuidv4 } from 'uuid';
import { handleFormatValue, MOVE_DEX_INFO, retryOperation } from '../utils.js';
import { ChainId } from '../../../types/base.js';
export const getRoutesHop = async (params) => {
    try {
        const rpcUrl = MVM_RPC_URL;
        const hopApiOptions = {
            api_key: 'hopapiMh262xgHkBMjbiuWDuzpDynhm24NAmqx',
            fee_bps: Number(params.commission || 0),
            charge_fees_in_sui: true,
            fee_wallet: '0x2',
        };
        const sdk = new HopApi(rpcUrl, hopApiOptions);
        const router = await retryOperation(async () => {
            return await sdk
                .fetchQuote({
                token_in: params.fromToken,
                token_out: params.toToken,
                amount_in: BigInt(params?.fromAmount || 0),
            })
                .catch((e) => {
                console.error('>>> e', e);
                throw new Error('Not found any routes from Hop');
            });
        });
        if (params.isBuildTx && router) {
            try {
                const txResponse = await sdk.fetchTx({
                    trade: router.trade,
                    sui_address: params.senderAddress || '',
                    gas_budget: 2e8, // optional default is 2e8
                    max_slippage_bps: Number(params.slippage || 1), // settings slippage or default 1%
                    return_output_coin_argument: false, // toggle to use the output coin in a ptb
                });
                return txResponse.transaction;
            }
            catch (e) {
                console.error('>>> e', e);
                throw new Error('Not build tx from Hop');
            }
        }
        return router;
    }
    catch (e) {
        console.error(e);
    }
};
export const formatRoutesHop = (hopRoutes, params) => {
    const hopInputAmount = hopRoutes?.value?.trade?.amount_in?.amount;
    const hopOutputAmount = hopRoutes?.value?.trade?.amount_out?.amount;
    const hopFromAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, hopInputAmount, hopOutputAmount).fromValue;
    const hopToAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, hopInputAmount, hopOutputAmount).toValue;
    const formatHopRouteSteps = Object.values(hopRoutes?.value?.trade?.nodes || {})?.map((node) => ({
        id: uuidv4(),
        type: 'swap',
        action: {
            fromChainId: ChainId.MOVE,
            fromAmount: node.amount_in.amount,
            fromToken: params.tokens?.find((t) => t.address === node.amount_in.token),
            toChainId: ChainId.MOVE,
            toToken: params.tokens?.find((t) => t.address === node.amount_out.token),
            slippage: params.options?.slippage,
            fromAddress: params.fromAddress,
        },
        estimate: {
            tool: node.pool.sui_exchange,
            fromAmount: node.amount_in.amount,
            toAmount: node.amount_out.amount,
            toAmountMin: node.amount_out.amount,
            approvalAddress: '',
            executionDuration: 1,
            feeCosts: [],
        },
        tool: node.pool.sui_exchange,
        toolDetails: {
            key: node.pool.sui_exchange,
            name: MOVE_DEX_INFO[node.pool.sui_exchange]
                ?.name || node.pool.sui_exchange,
            logoURI: MOVE_DEX_INFO[node.pool.sui_exchange]
                ?.image || 'https://cryptologos.cc/logos/sui-sui-logo.svg?v=035',
        },
    }));
    const hopPriceImpact = (hopToAmountUSD - hopFromAmountUSD) / hopFromAmountUSD;
    return {
        id: uuidv4(),
        fromToken: params.fromToken,
        toToken: params.toToken,
        fromAmount: hopInputAmount,
        toAmount: hopOutputAmount,
        fromAmountUSD: hopFromAmountUSD,
        toAmountUSD: hopToAmountUSD,
        fromChainId: ChainId.MOVE,
        toChainId: ChainId.MOVE,
        toAmountMin: hopOutputAmount,
        gasCostUSD: 0,
        steps: [
            {
                type: 'hop',
                id: uuidv4(),
                tool: 'hop',
                toolDetails: {
                    key: 'hop',
                    name: 'Hop',
                    logoURI: 'https://avatars.githubusercontent.com/u/161168710?s=200&v=4',
                },
                action: {
                    fromToken: params.fromToken,
                    fromAmount: hopInputAmount,
                    toToken: params.toToken,
                    fromChainId: ChainId.MOVE,
                    toChainId: ChainId.MOVE,
                    slippage: params.options?.slippage,
                    fromAddress: params.fromAddress,
                    toAddress: params.toAddress || params.fromAddress,
                },
                estimate: {
                    tool: 'hop',
                    approvalAddress: '',
                    toAmountMin: hopOutputAmount,
                    toAmount: hopOutputAmount,
                    fromAmount: hopInputAmount,
                    feeCosts: [],
                    // gasCosts: [],
                    executionDuration: 1,
                    fromAmountUSD: hopFromAmountUSD,
                    toAmountUSD: hopToAmountUSD,
                },
                includedSteps: formatHopRouteSteps,
                integrator: 'hop',
                execution: {
                    status: 'PENDING',
                    process: [],
                },
            },
        ],
        path: [],
        insurance: {},
        priceImpact: hopPriceImpact || 0,
    };
};
//# sourceMappingURL=index.js.map