import { setSuiClient, getQuote } from '@7kprotocol/sdk-ts';
import { SuiClient } from '@mysten/sui/client';
import { MVM_RPC_URL } from '../../../utils/mvm.js';
import { v4 as uuidv4 } from 'uuid';
import { flatten } from 'lodash';
import { handleFormatValue, mappingSuiToken, MOVE_DEX_INFO, retryOperation, } from '../utils.js';
import { ChainId } from '../../../types/base.js';
import { buildTx } from '@7kprotocol/sdk-ts';
export const getRoutesSeventK = async (params) => {
    try {
        const rpcUrl = MVM_RPC_URL;
        setSuiClient(new SuiClient({
            url: rpcUrl,
        }));
        const router = await retryOperation(async () => {
            return await getQuote({
                tokenIn: params.fromToken,
                tokenOut: params.toToken,
                amountIn: BigInt(params?.fromAmount || 0).toString(),
                commissionBps: Number(params.commission || 0),
            }).catch((e) => {
                console.error('>>> e', e);
                throw new Error('Not found any routes from 7K');
            });
        });
        if (params.isBuildTx && router) {
            try {
                const result = await buildTx({
                    quoteResponse: router,
                    accountAddress: params.senderAddress || '',
                    slippage: Number(params.slippage || 0.01), // settings slippage or default 1%
                    commission: {
                        partner: '0x4b8e9932393d1a73a9afeb253e6bdc6ea6f40cb72fc3ea174c233912043c1e36',
                        commissionBps: Number(params.commission || 0),
                    },
                });
                return result.tx;
            }
            catch (e) {
                console.error('>>> e', e);
                throw new Error('Not build tx from 7K');
            }
        }
        return router;
    }
    catch (e) {
        console.error(e);
    }
};
export const formatRoutesSeventK = (seventkRoutes, params) => {
    const seventkInputAmount = BigInt(seventkRoutes?.value?.swapAmountWithDecimal || 0);
    const seventkOutputAmount = BigInt(seventkRoutes?.value?.returnAmountAfterCommissionWithDecimal || 0);
    const formatListSeventKRoute = seventkRoutes?.value?.routes?.map((item) => item.hops);
    const seventkPriceImpact = seventkRoutes?.value?.priceImpact || 0;
    const formatSeventKRouteSteps = flatten(formatListSeventKRoute)?.map((node) => {
        const tokenInDecimal = node?.pool?.allTokens.find((item) => item.address === node.tokenIn) || {};
        const tokenOutDecimal = node?.pool?.allTokens.find((item) => item.address === node.tokenOut) || {};
        const formatTokenInAmount = Object.keys(tokenInDecimal).length !== 0
            ? Math.floor(Number(node.tokenInAmount) * 10 ** tokenInDecimal.decimal)
            : 0;
        const formatTokenOutAmount = Object.keys(tokenOutDecimal).length !== 0
            ? Math.floor(Number(node.tokenOutAmount) * 10 ** tokenOutDecimal.decimal)
            : 0;
        return {
            id: uuidv4(),
            type: 'swap',
            action: {
                fromChainId: ChainId.MOVE,
                fromAmount: formatTokenInAmount,
                fromToken: params.tokens?.find((t) => {
                    return mappingSuiToken(node.tokenIn) === t.address;
                }),
                toChainId: ChainId.MOVE,
                toToken: params.tokens?.find((t) => {
                    return mappingSuiToken(node.tokenOut) === t.address;
                }),
                slippage: params.options?.slippage,
                fromAddress: params.fromAddress,
            },
            estimate: {
                tool: node.pool.type.toUpperCase() || '7k pool',
                fromAmount: formatTokenInAmount,
                toAmount: formatTokenOutAmount,
                toAmountMin: formatTokenOutAmount,
                approvalAddress: '',
                executionDuration: 1,
                feeCosts: [],
            },
            tool: node.pool.type.toUpperCase() || '7k pool',
            toolDetails: {
                key: node.pool.type.toUpperCase() || '7k pool',
                name: MOVE_DEX_INFO[node.pool.type.toUpperCase()]?.name ||
                    node.pool.type.toUpperCase() ||
                    '7k pool',
                logoURI: MOVE_DEX_INFO[node.pool.type.toUpperCase()]?.image || 'https://cryptologos.cc/logos/sui-sui-logo.svg?v=035',
            },
        };
    });
    const seventkFromAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, seventkInputAmount, seventkOutputAmount).fromValue;
    const seventkToAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, seventkInputAmount, seventkOutputAmount).toValue;
    return {
        id: uuidv4(),
        fromToken: params.fromToken,
        toToken: params.toToken,
        fromAmount: seventkInputAmount,
        toAmount: seventkOutputAmount,
        fromAmountUSD: seventkFromAmountUSD,
        toAmountUSD: seventkToAmountUSD,
        fromChainId: ChainId.MOVE,
        toChainId: ChainId.MOVE,
        toAmountMin: seventkOutputAmount,
        gasCostUSD: 0,
        steps: [
            {
                type: '7k',
                id: uuidv4(),
                tool: '7k',
                toolDetails: {
                    key: '7k',
                    name: '7K',
                    logoURI: 'https://avatars.githubusercontent.com/u/171641380?s=48&v=4',
                },
                action: {
                    fromToken: params.fromToken,
                    fromAmount: seventkInputAmount,
                    toToken: params.toToken,
                    fromChainId: ChainId.MOVE,
                    toChainId: ChainId.MOVE,
                    slippage: params.options?.slippage,
                    fromAddress: params.fromAddress,
                    toAddress: params.toAddress || params.fromAddress,
                },
                estimate: {
                    tool: 'flowx',
                    approvalAddress: '',
                    toAmountMin: seventkOutputAmount,
                    toAmount: seventkOutputAmount,
                    fromAmount: seventkInputAmount,
                    feeCosts: [],
                    // gasCosts: [],
                    executionDuration: 1,
                    fromAmountUSD: seventkFromAmountUSD,
                    toAmountUSD: seventkToAmountUSD,
                },
                includedSteps: formatSeventKRouteSteps,
                integrator: '7K',
                execution: {
                    status: 'PENDING',
                    process: [],
                },
            },
        ],
        path: [],
        insurance: {},
        priceImpact: seventkPriceImpact || 0,
    };
};
//# sourceMappingURL=index.js.map