import { v4 as uuidv4 } from 'uuid';
import { handleFormatValue, retryOperation } from '../utils.js';
import { ChainId } from '../../../types/base.js';
import { BigNumber } from 'bignumber.js';
import axios from 'axios';
export const getRoutesOrca = async (params) => {
    try {
        const router = await retryOperation(async () => {
            const formatFromTokenCA = params.fromToken === '11111111111111111111111111111111'
                ? 'So11111111111111111111111111111111111111112'
                : params.fromToken;
            const formatToTokenCA = params.toToken === '11111111111111111111111111111111'
                ? 'So11111111111111111111111111111111111111112'
                : params.toToken;
            const response = await axios.get(`https://pools-api.mainnet.orca.so/swap-quote?from=${formatFromTokenCA}&to=${formatToTokenCA}&amount=${params.fromAmount}&&isLegacy=false&amountIsInput=true&includeData=true&includeComputeBudget=false&maxTxSize=1180&wallet=${params.wallet}`);
            return response?.data;
        });
        return router;
    }
    catch (e) {
        console.error(e);
    }
};
export const formatRoutesOrca = (orcaRoutes, params) => {
    const orcaInputAmount = new BigNumber(Number(orcaRoutes?.value?.data?.swap?.inputAmount || 0));
    const orcaOutputAmount = new BigNumber(Number(orcaRoutes?.value?.data?.swap?.outputAmount || 0));
    const orcaFromAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, orcaInputAmount, orcaOutputAmount).fromValue;
    const orcaToAmountUSD = handleFormatValue(params?.fromToken?.priceUSD, params?.fromToken?.decimals, params?.toToken?.priceUSD, params?.toToken?.decimals, orcaInputAmount, orcaOutputAmount).toValue;
    const orcaPriceImpact = Number(orcaRoutes?.value?.data?.price_impact || 0);
    const formatOrcaRouteSteps = [
        {
            id: uuidv4(),
            type: 'swap',
            action: {
                fromChainId: ChainId.SOL,
                fromAmount: orcaInputAmount,
                fromToken: params.fromToken,
                toChainId: ChainId.SOL,
                toToken: params.toToken,
                slippage: params.options?.slippage,
                fromAddress: params.fromAddress,
            },
            estimate: {
                tool: 'orca',
                fromAmount: orcaInputAmount,
                toAmount: orcaOutputAmount,
                toAmountMin: orcaOutputAmount,
                approvalAddress: '',
                executionDuration: 1,
                feeCosts: [],
                gasCosts: [],
            },
            tool: 'orca',
            toolDetails: {
                key: 'orca',
                name: 'Orca',
                logoURI: 'https://icons.llamao.fi/icons/protocols/orca?w=48&h=48',
            },
        },
    ];
    return {
        id: uuidv4(),
        fromToken: params.fromToken,
        toToken: params.toToken,
        fromAmount: orcaInputAmount,
        toAmount: orcaOutputAmount,
        fromAmountUSD: orcaFromAmountUSD,
        toAmountUSD: orcaToAmountUSD,
        fromChainId: ChainId.SOL,
        toChainId: ChainId.SOL,
        toAmountMin: orcaOutputAmount,
        gasCostUSD: 0,
        steps: [
            {
                type: 'orca',
                id: uuidv4(),
                tool: 'orca',
                toolDetails: {
                    key: 'orca',
                    name: 'Orca',
                    logoURI: 'https://icons.llamao.fi/icons/protocols/orca?w=48&h=48',
                },
                action: {
                    fromToken: params.fromToken,
                    fromAmount: orcaInputAmount,
                    toToken: params.toToken,
                    fromChainId: ChainId.SOL,
                    toChainId: ChainId.SOL,
                    slippage: params.options?.slippage,
                    fromAddress: params.fromAddress,
                    toAddress: params.toAddress || params.fromAddress,
                },
                estimate: {
                    tool: 'orca',
                    approvalAddress: '',
                    toAmountMin: orcaOutputAmount,
                    toAmount: orcaOutputAmount,
                    fromAmount: orcaInputAmount,
                    feeCosts: [],
                    // gasCosts: [],
                    executionDuration: 1,
                    fromAmountUSD: orcaFromAmountUSD,
                    toAmountUSD: orcaToAmountUSD,
                },
                includedSteps: formatOrcaRouteSteps,
                integrator: 'orca',
                execution: {
                    status: 'PENDING',
                    process: [],
                },
            },
        ],
        path: [],
        insurance: {},
        priceImpact: orcaPriceImpact || 0,
    };
};
//# sourceMappingURL=index.js.map