const delay = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
export const retryOperation = async (operation, maxRetries = 3, delayMs = 1000) => {
    let lastError;
    for (let attempt = 1; attempt <= maxRetries; attempt++) {
        try {
            return await operation();
        }
        catch (error) {
            lastError = error;
            console.error(`Attempt ${attempt} failed:`, error);
            if (attempt < maxRetries) {
                await delay(delayMs * attempt); // Exponential backoff
                continue;
            }
        }
    }
    throw lastError;
};
export const handleFormatValue = (fromTokenPriceUSD, fromTokenDecimals, toTokenPriceUSD, toTokenDecimals, inputAmount, outputAmount) => {
    const fromValue = fromTokenPriceUSD
        ? (Number(inputAmount) * Number(fromTokenPriceUSD)) /
            10 ** (fromTokenDecimals || 18)
        : 0;
    const toValue = toTokenPriceUSD
        ? (Number(outputAmount) * Number(toTokenPriceUSD)) /
            10 ** (toTokenDecimals || 18)
        : 0;
    return {
        fromValue: fromValue || 0,
        toValue: toValue || 0,
    };
};
//# sourceMappingURL=utils.js.map