import { isAddress as isEVMAddress } from 'viem';
import { isAddress as isTVMAddress } from '../core/TVM/isAddress.js';
import { isAddress as isMVMAddress } from '../core/MVM/isAddress.js';
import { isAddress as isSVMAddress } from '../core/Solana/isAddress.js';
import { isAddress as isEclipseAddress } from '../core/Eclipse/isAddress.js';
import { ChainId } from '../types/base.js';
export var ChainType;
(function (ChainType) {
    ChainType["EVM"] = "EVM";
    // Solana virtual machine
    ChainType["SVM"] = "SVM";
    // Unspent transaction output (e.g. Bitcoin)
    ChainType["UTXO"] = "UTXO";
    // Custom ChainType
    ChainType["TVM"] = "TVM";
    ChainType["MVM"] = "MVM";
    ChainType["ECLIPSE"] = "ECLIPSE";
})(ChainType || (ChainType = {}));
const chainTypeAddressValidation = {
    [ChainType.EVM]: isEVMAddress,
    [ChainType.SVM]: isSVMAddress,
    [ChainType.TVM]: isTVMAddress,
    [ChainType.MVM]: isMVMAddress,
    [ChainType.ECLIPSE]: isEclipseAddress,
    [ChainType.UTXO]: () => false,
};
export const getChainTypeFromAddress = (address) => {
    for (const chainType in chainTypeAddressValidation) {
        const isChainType = chainTypeAddressValidation[chainType](address);
        if (isChainType) {
            return chainType;
        }
    }
};
export const defaultChainIdsByType = {
    [ChainType.EVM]: ChainId.ETH,
    [ChainType.SVM]: ChainId.SOL,
    [ChainType.UTXO]: ChainId.BTC,
    [ChainType.TVM]: ChainId.TON,
    [ChainType.MVM]: ChainId.MOVE,
    [ChainType.ECLIPSE]: ChainId.ECLIPSE,
};
//# sourceMappingURL=chainType.js.map