import { getToken, type TokensResponse } from '@lifi/sdk';
import { useQuery, useQueryClient } from '@tanstack/react-query';
import type { TokenAmount } from '../types/token.js';
import { ChainId } from '../types/base.js';

export const useTokenSearch = (
  chainId?: number,
  tokenQuery?: string,
  enabled?: boolean,
) => {
  const queryClient = useQueryClient();
  const { data, isLoading } = useQuery({
    queryKey: ['token-search', chainId, tokenQuery],
    queryFn: async ({ queryKey: [, chainId, tokenQuery], signal }) => {
      if (
        chainId === ChainId.TON ||
        chainId === ChainId.MOVE ||
        chainId === ChainId.ECLIPSE
      ) {
        return {} as TokenAmount;
      }

      // TODO: search token if not found in list
      const token = await getToken(chainId as any, tokenQuery as string, {
        signal,
      });

      if (token) {
        queryClient.setQueriesData<TokensResponse>(
          { queryKey: ['tokens'] },
          (data) => {
            if (
              data &&
              !data.tokens[chainId as number]?.some(
                (t) => t.address === token.address,
              )
            ) {
              const clonedData = { ...data };
              clonedData.tokens[chainId as number]?.push(token);
              return clonedData;
            }
          },
        );
      }
      return token as any;
    },

    enabled: Boolean(chainId && tokenQuery && enabled),
    retry: false,
  });
  return {
    token: data,
    isLoading,
  };
};
