import { useTranslation } from 'react-i18next';
import { PageContainer } from '../../components/PageContainer.js';
import { useHeader } from '../../hooks/useHeader.js';
// import { BridgeAndExchangeSettings } from './BridgeAndExchangeSettings.js';
// import { GasPriceSettings } from './GasPriceSettings.js';
import { LanguageSetting } from './LanguageSetting.js';
import { ResetSettingsButton } from './ResetSettingsButton.js';
// import { RoutePrioritySettings } from './RoutePrioritySettings.js';
import { SettingsList } from './SettingsCard/SettingCard.style.js';
import { SettingsCardAccordion } from './SettingsCard/SettingsAccordian.js';
import { SlippageSettings } from './SlippageSettings/SlippageSettings.js';
import { ThemeSettings } from './ThemeSettings.js';
import { ShioSettings } from './ShioSettings/ShioSettings.js';
import { useChain } from '../../hooks/useChain.js';
import { useAccount } from '../../hooks/useAccount.js';
import { useFieldValues } from '../../stores/form/useFieldValues.js';

export const SettingsPage = () => {
  const { t } = useTranslation();
  useHeader(t(`header.settings`));

  const [fromChainId] = useFieldValues('fromChain');
  const { chain } = useChain(fromChainId);
  const { account } = useAccount({ chainType: chain?.chainType });

  return (
    <PageContainer bottomGutters>
      <SettingsList>
        <SettingsCardAccordion>
          <ThemeSettings />
          <LanguageSetting />
          {/* <RoutePrioritySettings />
          <GasPriceSettings /> */}
          <SlippageSettings />
          {/* <BridgeAndExchangeSettings type="Bridges" />
          <BridgeAndExchangeSettings type="Exchanges" /> */}

          {account.isConnected && account.chainType === 'MVM' && (
            <ShioSettings />
          )}
        </SettingsCardAccordion>
      </SettingsList>
      <ResetSettingsButton />
    </PageContainer>
  );
};
