import { Box, ButtonBase, InputBase, alpha, styled } from '@mui/material';

export const SettingsFieldSet = styled(Box)(({ theme }) => ({
  display: 'flex',
  backgroundColor:
    theme.palette.mode === 'light'
      ? alpha(theme.palette.common.black, 0.04)
      : alpha(theme.palette.common.white, 0.08),
  borderRadius: theme.shape.borderRadius,
  padding: theme.spacing(0.5),
  gap: theme.spacing(0.5),
  height: '3.5rem',
}));

export const ModeToggleButton = styled(ButtonBase)<{ selected?: boolean }>(
  ({ theme, selected }) => ({
    flex: 1,
    borderRadius: theme.shape.borderRadius,
    padding: theme.spacing(1),
    backgroundColor: selected
      ? theme.palette.mode === 'light'
        ? theme.palette.common.white
        : alpha(theme.palette.common.white, 0.16)
      : 'transparent',
    color: selected ? theme.palette.text.primary : theme.palette.text.secondary,
    transition: theme.transitions.create(['background-color', 'color']),
    '&:hover': {
      backgroundColor: selected
        ? theme.palette.mode === 'light'
          ? theme.palette.common.white
          : alpha(theme.palette.common.white, 0.16)
        : theme.palette.mode === 'light'
          ? alpha(theme.palette.common.black, 0.04)
          : alpha(theme.palette.common.white, 0.08),
    },
  }),
);

export const GasInput = styled(InputBase)(({ theme }) => ({
  flex: 1,
  backgroundColor:
    theme.palette.mode === 'light'
      ? alpha(theme.palette.common.black, 0.04)
      : alpha(theme.palette.common.white, 0.08),
  borderRadius: theme.shape.borderRadius,
  padding: theme.spacing(1.5),
  '& input': {
    textAlign: 'right',
    padding: 0,
    fontSize: '1rem',
    '&::placeholder': {
      color: theme.palette.text.secondary,
      opacity: 0.5,
    },
  },
  '&:hover': {
    backgroundColor:
      theme.palette.mode === 'light'
        ? alpha(theme.palette.common.black, 0.06)
        : alpha(theme.palette.common.white, 0.12),
  },
  '&.Mui-focused': {
    backgroundColor:
      theme.palette.mode === 'light'
        ? alpha(theme.palette.common.black, 0.08)
        : alpha(theme.palette.common.white, 0.16),
  },
}));

export const GasInputContainer = styled(Box)(({ theme }) => ({
  display: 'flex',
  flexDirection: 'column',
  gap: theme.spacing(1),
  marginTop: theme.spacing(2),
  padding: theme.spacing(1.5),
  backgroundColor:
    theme.palette.mode === 'light'
      ? alpha(theme.palette.common.black, 0.02)
      : alpha(theme.palette.common.white, 0.04),
  borderRadius: theme.shape.borderRadius,
}));

export const GasInputLabel = styled(Box)(({ theme }) => ({
  display: 'flex',
  justifyContent: 'space-between',
  alignItems: 'center',
  color: theme.palette.text.secondary,
  '& .MuiTypography-root': {
    fontSize: '0.875rem',
    fontWeight: 500,
  },
  '& .MuiBox-root': {
    display: 'flex',
    alignItems: 'center',
    gap: theme.spacing(0.5),
  },
}));

export const GasValueDisplay = styled(Box)(({ theme }) => ({
  fontSize: '0.775rem',
  color: theme.palette.text.secondary,
  display: 'flex',
  alignItems: 'center',
  gap: theme.spacing(0.5),
  '& strong': {
    color: theme.palette.text.primary,
    fontWeight: 500,
  },
}));

export const WarningContainer = styled(Box)(({ theme }) => ({
  display: 'flex',
  alignItems: 'center',
  gap: theme.spacing(1),
  marginTop: theme.spacing(1),
  padding: theme.spacing(1),
  borderRadius: theme.shape.borderRadius,
  backgroundColor: alpha(theme.palette.warning.main, 0.1),
}));

export const PoweredByContainer = styled(Box)(({ theme }) => ({
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  gap: theme.spacing(1),
  padding: theme.spacing(2, 0),
  color: theme.palette.text.secondary,
  fontSize: '0.875rem',
  '& .logo-container': {
    display: 'flex',
    alignItems: 'center',
    gap: theme.spacing(0.5),
  },
  '& img': {
    width: 16,
    height: 16,
    objectFit: 'contain',
  },
  '& .shio-text': {
    color: theme.palette.text.primary,
    fontWeight: 500,
  },
}));
