import {
  createContext,
  useContext,
  useEffect,
  useState,
  useMemo,
  type FC,
  type PropsWithChildren,
} from 'react';
import {
  // @ts-ignore
  WalletProvider,
  // @ts-ignore
  PhantomWallet,
  // @ts-ignore
  SlushWallet,
  // @ts-ignore
  SuietWallet,
  // @ts-ignore
  ConnectModal,
  // @ts-ignore
  defineSlushWallet,
  // @ts-ignore
  useWallet,
} from '@suiet/wallet-kit';
import { ShioFastRpcUrl } from 'shio-fast-sdk';
import { MVM_RPC_URL, SHIO_DEFAULT_RPC_URL } from '../../../utils/mvm.js';
import { useSettings } from '../../../stores/settings/useSettings.js';

const slushWallet = defineSlushWallet({
  appName: 'Nimbus',
  network: 'mainnet',
});

type MVMBaseContextType = {
  moveWalletInstance?: any;
  isConnected: boolean;
};

export const MVMBaseContext = createContext<MVMBaseContextType>({
  moveWalletInstance: null,
  isConnected: false,
});

export const useMove = () => useContext(MVMBaseContext);

export const MVMBaseProvider: FC<PropsWithChildren & any> = ({ children }) => {
  const wallet = useWallet();
  const [showModal, setShowModal] = useState<boolean>(false);
  const [isConnected, setIsConnected] = useState<boolean>(false);

  useEffect(() => {
    const timer = setTimeout(() => {
      setIsConnected(false);
    }, 2000); // 2s

    return () => clearTimeout(timer);
  }, [isConnected]);

  const onConnectSuccess = (msg: any) => {
    // eslint-disable-next-line no-console
    console.log('Success connect: ', msg);
    setShowModal(false);
    setIsConnected(true);
  };

  const onConnectError = (msg: any) => {
    // eslint-disable-next-line no-console
    console.error('Error connect', msg);
    setIsConnected(false);
  };

  const handleSetState = () => {
    (wallet as any).toggleSelect = () => {
      setShowModal(!showModal);
    };
  };

  useEffect(() => {
    handleSetState();
    // eslint-disable-next-line  react-hooks/exhaustive-deps
  }, [wallet]);

  const { mevProtection, transactionMode } = useSettings([
    'mevProtection',
    'transactionMode',
  ]);

  const chains = useMemo(() => {
    const rpcUrl = !mevProtection
      ? MVM_RPC_URL
      : transactionMode === 'default'
        ? SHIO_DEFAULT_RPC_URL
        : ShioFastRpcUrl;

    return [
      {
        id: 'sui:mainnet',
        name: 'Mainnet',
        rpcUrl: rpcUrl,
        network: 'mainnet',
        chainId: 'sui:mainnet',
      },
    ];
  }, [mevProtection, transactionMode]);

  return (
    <WalletProvider
      key={chains[0].rpcUrl}
      defaultWallets={[SlushWallet, slushWallet, SuietWallet, PhantomWallet]}
      autoConnect={true}
      chains={chains}
    >
      <MVMBaseContext.Provider
        value={{
          moveWalletInstance: wallet,
          isConnected,
        }}
      >
        {children}
        <ConnectModal
          open={showModal}
          onOpenChange={(open: boolean) => setShowModal(open)}
          onConnectSuccess={onConnectSuccess}
          onConnectError={onConnectError}
        ></ConnectModal>
      </MVMBaseContext.Provider>
    </WalletProvider>
  );
};
