import { TonConnectUI } from '@tonconnect/ui';
import {
  createContext,
  useContext,
  useEffect,
  useRef,
  useState,
  type FC,
  type PropsWithChildren,
} from 'react';
import { useWidgetConfig } from '../../WidgetProvider/WidgetProvider.js';

type TVMBaseContextType = {
  tonConnectUI?: TonConnectUI;
  setTonConnectUI: (tonConnectUI: TonConnectUI) => void;
};

export const TVMBaseContext = createContext<TVMBaseContextType>({
  tonConnectUI: undefined,
  setTonConnectUI: (_: TonConnectUI) => {},
});

export const useTon = () => useContext(TVMBaseContext);
export const TVMBaseProvider: FC<PropsWithChildren> = ({ children }) => {
  const [tonConnectUI, setTonConnectUI] = useState<TonConnectUI | undefined>();
  const { tonConnectUI: tonConnector } = useWidgetConfig();
  const effectRan = useRef(false);

  useEffect(() => {
    if (tonConnector) {
      setTonConnectUI(tonConnector);
    } else {
      if (!effectRan.current) {
        setTonConnectUI(
          new TonConnectUI({
            manifestUrl:
              'https://gist.githubusercontent.com/toannhu96/0f9cdecbfa668157a901c76f41ced0f0/raw/78bdaee6e4f101032bb97cfece71b79b7f28fbd5/tonconnect-manifest.json',
          }),
        );
      }
    }

    return () => {
      effectRan.current = true;
    };
  }, [setTonConnectUI, tonConnector]);

  return (
    <TVMBaseContext.Provider
      value={{
        tonConnectUI,
        setTonConnectUI,
      }}
    >
      {children}
    </TVMBaseContext.Provider>
  );
};
