import { type FC, type PropsWithChildren } from 'react';
import { ChainType } from '../../../utils/chainType.js';
import { isItemAllowed } from '../../../utils/item.js';
import { useWidgetConfig } from '../../WidgetProvider/WidgetProvider.js';
import { TVMBaseProvider } from './TVMBaseProvider.js';

export function useInTonContext(): boolean {
  const { chains } = useWidgetConfig();

  return (
    Boolean(customElements.get('tc-root')) &&
    isItemAllowed(ChainType.TVM, chains?.types)
  );
}

export const TVMProvider: FC<PropsWithChildren> = ({ children }) => {
  const inTonContext = useInTonContext();
  const { tonConnectUI, chains } = useWidgetConfig();

  const isAllowTVM = isItemAllowed(ChainType.TVM, chains?.types);

  if (inTonContext && !tonConnectUI) {
    console.error(
      'TVMProvider: tonConnectUI is required if TonConnect has been initialized',
    );
  }

  return isAllowTVM ? (
    <TVMBaseProvider>{children}</TVMBaseProvider>
  ) : (
    <>{children}</>
  );
};
