import axios from 'axios';
import { flatten } from 'lodash';
import { v4 as uuidv4 } from 'uuid';
import { handleFormatValue } from '../utils.js';
import { ChainId } from '../../../types/base.js';

import type { RoutesOrcaParams } from './types.js';

export const handleGetRoutesOrca = async (params: any) => {
  try {
    return await axios
      .get(
        `https://pools-api-eclipse.mainnet.orca.so/swap-quote?from=${params.fromToken}&to=${params.toToken}&amount=${params.fromAmount}&isLegacy=false&amountIsInput=true&includeData=true&includeComputeBudget=false&maxTxSize=1185&wallet=${params.account || 'Bh75eEDksaoBV9GBf7iJU9EaWQUixUyC52rMr4BH3BH6'}`,
      )
      .then((res) => res?.data?.data);
  } catch (e) {
    console.error(e);
  }
};

export const handleTrxOrca = async (params: any, swap: any) => {
  try {
    const txInstructions = await axios
      .post(
        'https://pools-api-eclipse.mainnet.orca.so/swap-prepare-instructions',
        {
          amountIsInput: true,
          swap,
          wallet: params.account,
          slippage: params.slippage || '0.01',
        },
      )
      .then((res) => res?.data?.data);

    return txInstructions;
  } catch (e) {
    console.error('Error in handleTrxOrca:', e);
    throw e;
  }
};

export const getRoutesOrca = async (params: RoutesOrcaParams) => {
  try {
    const router = await handleGetRoutesOrca(params).catch((e) => {
      console.error('>>> e', e);
      throw new Error('Not found any routes from Orca');
    });

    return router;
  } catch (e) {
    console.error('Error in getRoutesOrca:', e);
    throw e;
  }
};

export const formatRoutesOrca = (orcaRoutes: any, params: any) => {
  const orcaInputAmount = (orcaRoutes as any)?.value?.swap?.inputAmount;
  const orcaOutputAmount = (orcaRoutes as any)?.value?.swap?.outputAmount;

  const orcaFromAmountUSD = handleFormatValue(
    params?.fromToken?.priceUSD,
    params?.fromToken?.decimals,
    Number(params?.toToken?.priceUSD),
    params?.toToken?.decimals,
    orcaInputAmount,
    orcaOutputAmount,
  ).fromValue;

  const orcaToAmountUSD = handleFormatValue(
    params?.fromToken?.priceUSD,
    params?.fromToken?.decimals,
    Number(params?.toToken?.priceUSD),
    params?.toToken?.decimals,
    orcaInputAmount,
    orcaOutputAmount,
  ).toValue;

  const formatListOrcaRoute = (orcaRoutes as any)?.value?.swap?.split;

  const orcaPriceImpact = (orcaRoutes as any)?.value?.price_impact;

  const formatOrcaRouteSteps = flatten(formatListOrcaRoute)?.map(
    (node: any) => {
      return {
        id: uuidv4(),
        type: 'swap',
        action: {
          fromChainId: ChainId.ECLIPSE,
          fromAmount: node.input.amount,
          fromToken: params.fromToken,
          toChainId: ChainId.ECLIPSE,
          toToken: params.toToken,
          slippage: params.options?.slippage,
          fromAddress: params.fromAddress,
        },
        estimate: {
          tool: 'orca',
          fromAmount: node.input.amount,
          toAmount: node.output.amount,
          toAmountMin: node.output.amount,
          approvalAddress: '',
          executionDuration: 1,
          feeCosts: [],
          gasCosts: [],
        },
        tool: 'orca',
        toolDetails: {
          key: 'orca',
          name: 'Orca',
          logoURI:
            'https://s2.coinmarketcap.com/static/img/coins/64x64/11165.png',
        },
      };
    },
  );

  return {
    id: uuidv4(),
    fromToken: params.fromToken,
    toToken: params.toToken,
    fromAmount: orcaInputAmount,
    toAmount: orcaOutputAmount,
    fromAmountUSD: orcaFromAmountUSD,
    toAmountUSD: orcaToAmountUSD,
    fromChainId: ChainId.ECLIPSE,
    toChainId: ChainId.ECLIPSE,
    toAmountMin: orcaOutputAmount,

    gasCostUSD: 0,

    steps: [
      {
        type: 'orca',
        id: uuidv4(),
        tool: 'orca',
        toolDetails: {
          key: 'orca',
          name: 'Orca',
          logoURI:
            'https://s2.coinmarketcap.com/static/img/coins/64x64/11165.png',
        },

        action: {
          fromToken: params.fromToken,
          fromAmount: orcaInputAmount,
          toToken: params.toToken,
          fromChainId: ChainId.ECLIPSE,
          toChainId: ChainId.ECLIPSE,
          slippage: params.options?.slippage,
          fromAddress: params.fromAddress,
          toAddress: params.toAddress || params.fromAddress,
        },
        estimate: {
          tool: 'orca',
          approvalAddress: '',
          toAmountMin: orcaOutputAmount,
          toAmount: orcaOutputAmount,
          fromAmount: orcaInputAmount,
          feeCosts: [],
          // gasCosts: [],
          executionDuration: 1,
          fromAmountUSD: orcaFromAmountUSD,
          toAmountUSD: orcaToAmountUSD,
        },

        includedSteps: formatOrcaRouteSteps,
        integrator: 'orca',
        execution: {
          status: 'PENDING',
          process: [],
        },
      },
    ],
    path: [],
    insurance: {},
    priceImpact: orcaPriceImpact || 0,
  };
};
